@@ -23,7 +23,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __DBUFFER_H__
 
 #include "VCommon.h"
-#include "VExcept.h"
+#include "helpers/VExcept.h"
 
 namespace vapp {
 
