@@ -173,11 +173,12 @@ namespace vapp {
 	UI window
   ===========================================================================*/
   enum UIMsgBoxButton {
-    UI_MSGBOX_NOTHING   = 0,    
-    UI_MSGBOX_OK        = 1,
-    UI_MSGBOX_CANCEL    = 2,
-    UI_MSGBOX_YES       = 4,
-    UI_MSGBOX_NO        = 8
+    UI_MSGBOX_NOTHING     = 0,    
+    UI_MSGBOX_OK          = 1,
+    UI_MSGBOX_CANCEL      = 2,
+    UI_MSGBOX_YES         = 4,
+    UI_MSGBOX_NO          = 8,
+    UI_MSGBOX_YES_FOR_ALL = 16
   };
   
   class UIWindow {
@@ -597,27 +598,8 @@ namespace vapp {
   class UIList : public UIWindow {
     public:
       UIList() {}
-      UIList(UIWindow *pParent,int x=0,int y=0,std::string Caption="",int nWidth=0,int nHeight=0) {      
-        initW(pParent,x,y,Caption,nWidth,nHeight);        
-        m_nScroll = 0;
-        m_nSelected = 0;
-        m_pEnterButton = NULL;
-        m_bSort = false;
-        m_bItemActivated = false;
-        
-        m_bScrollDownPressed = m_bScrollUpPressed = false;
-        
-        m_bScrollDownHover = m_bScrollUpHover = false;
-        
-	m_bClicked = false;
-
-	m_bChanged = false;
-
-	m_lastRefreshTime = getApp()->getRealTime();
-
-        unhideAllColumns();
-      }      
-      virtual ~UIList() {_FreeUIList();}
+      UIList(UIWindow *pParent,int x=0,int y=0,std::string Caption="",int nWidth=0,int nHeight=0);
+      virtual ~UIList();
 
       /* Methods */
       virtual void paint(void);
@@ -631,35 +613,41 @@ namespace vapp {
       virtual void mouseHover(int x,int y);      
       virtual bool offerActivation(void);
       virtual bool keyDown(int nKey,int nChar);
+
+      virtual std::string subContextHelp(int x,int y);
       
       UIListEntry *addEntry(std::string Text,void *pvUser=NULL);
       void clear(void);
       
       /* Data interface */
-      std::vector<UIListEntry *> &getEntries(void) {return m_Entries;}      
-      std::vector<std::string> &getColumns(void) {return m_Columns;}
-      int getSelected(void) {return m_nSelected;}
-      void setSelected(int n) {m_bChanged = true; m_nSelected = n;}
-      void addColumn(std::string Title,int nWidth) {m_Columns.push_back(Title); m_ColumnWidths.push_back(nWidth);}
-      void setEnterButton(UIButton *pButton) {m_pEnterButton = pButton;}
-      bool isItemActivated(void) {return m_bItemActivated;}
-      void setHideColumn(int n) {m_nColumnHideFlags |= (1<<n);}
-      void unhideAllColumns(void) {m_nColumnHideFlags=0;}
-      void setSort(bool bSort) {m_bSort=bSort;}
-      
-      bool isClicked(void) {return m_bClicked;}
-      void setClicked(bool b) {m_bClicked=b;}
+      std::vector<UIListEntry *> &getEntries();
+      std::vector<std::string> &getColumns();
+      int getSelected();
+      void setSelected(int n);
+      void addColumn(std::string Title,int nWidth,const std::string &Help = "");
+      void setEnterButton(UIButton *pButton);
+      bool isItemActivated();
+      void setHideColumn(int n);
+      void unhideAllColumns(void);
+      void setSort(bool bSort, int(*f)(void *pvUser1, void *pvUser2) = NULL);
+      void setNumeroted(bool bNumeroted);
 
-      bool isChanged(void) {return m_bChanged;}
-      void setChanged(bool b) {m_bChanged=b;}
+      bool isClicked(void);
+      void setClicked(bool b);
+
+      bool isChanged(void);
+      void setChanged(bool b);
 
     private:
       /* Data */
       bool m_bChanged;
       float m_lastRefreshTime;
       bool m_bSort;
+      bool m_bNumeroted;
+      int(*m_fsort)(void *pvUser1, void *pvUser2);
       std::vector<UIListEntry *> m_Entries;
       std::vector<std::string> m_Columns;
+      std::vector<std::string> m_ColumnHelpStrings;
       std::vector<int> m_ColumnWidths;
       unsigned int m_nColumnHideFlags;
       int m_nSelected;
@@ -672,12 +660,43 @@ namespace vapp {
       bool m_bScrollUpHover,m_bScrollDownHover;
       
       bool m_bClicked;
+      bool  m_bScrolling;
+
+      /* draw */
+      int HeaderHeight();
+      int HeaderSubBorderHeight();
+      int RowHeight();
+      int LineMargeX();
+      int LineMargeY();
+      int LinesStartX();
+      int LinesStartY();
+      int LinesWidth();
+      int LinesHeight();
+
+      int ScrollBarArrowWidth();
+      int ScrollBarArrowHeight();
+      int ScrollBarBarWidth();
+      int ScrollBarBarHeight();
+      int ScrollBarScrollerWidth();
+      int ScrollBarScrollerHeight();
+      int ScrollBarScrollerStartX();
+      int ScrollBarScrollerStartY();
+      void setScrollBarScrollerStartY(float y);
+      float ScrollNbVisibleItems();
+      
+      int m_headerHeight;
+      int m_headerSubBorderHeight;
+      int m_rowHeight;
+      int m_lineMargeX, m_lineMargeY;
+      int m_scrollBarArrowWidth;
+      int m_scrollBarArrowHeight;
 
       /* Helpers */
       void _FreeUIList(void);
       void _NewlySelectedItem(void);
       void _Scroll(int nPixels);
       void _refreshByTime();
+      void _mouseDownManageScrollBar(int x, int y);
   };
 
 	/*===========================================================================
@@ -768,7 +787,7 @@ namespace vapp {
       virtual bool keyUp(int nKey);  
       
       void deactivate(UIWindow *pWindow);
-      
+
       void enableContextMenuDrawing(bool b) {m_bShowContextMenu=b;}
       void clearContext(void) {m_CurrentContextHelp = "";}
       
