@@ -24,7 +24,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "VCommon.h"
 #include "VApp.h"
-#include "LevelSrc.h"
+#include "xmscene/Level.h"
 #include "MotoGame.h"
 #include "VTexture.h"
 #include "Renderer.h"
@@ -39,12 +39,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "GUIXMoto.h"
 #include "Stats.h"
 #include "Credits.h"
+#include "LevelsManager.h"
 
 #define PRESTART_ANIMATION_TIME 2.0
 #define PRESTART_ANIMATION_LEVEL_MSG_DURATION 1.0
 #define PRESTART_ANIMATION_MARGIN_SIZE 5
 #define PRESTART_ANIMATION_CURVE 3.0
-  
+
 namespace vapp {
 
   /*===========================================================================
@@ -56,7 +57,8 @@ namespace vapp {
     GS_PREPLAYING,            /* Just before the game start */
     GS_PLAYING,               /* Playing the game */
     GS_PAUSE,                 /* Paused from GS_PLAYING */
-    GS_JUSTDEAD,              /* Head-banging too much */
+    GS_DEADJUST,              /* just dead */
+    GS_DEADMENU,              /* Head-banging too much */
     GS_EDIT_PROFILES,         /* In profile editor */
     GS_FINISHED,              /* Finished a level */
     GS_REPLAYING,             /* Replaying */
@@ -86,18 +88,6 @@ namespace vapp {
   };
 #endif
 
-  /*===========================================================================
-  Level packs
-  ===========================================================================*/
-  struct LevelPack {
-    std::string Name;
-    std::vector<LevelSrc *> Levels;
-    
-    /* Hints */
-    bool bShowTimes;
-    bool bShowWebTimes;
-  };
-
   /*===========================================================================
   Game application
   ===========================================================================*/
@@ -122,8 +112,8 @@ namespace vapp {
                  m_bEnableDeathAnim=true;
                  m_pQuitMsgBox=NULL;
                  m_pNotifyMsgBox=NULL;
+                 m_pInfoMsgBox=NULL;
 #if defined(SUPPORT_WEBACCESS)
-                 m_pDownloadMsgBox=NULL;
                  m_pNewLevelsAvailIcon=NULL;
                  m_pWebConfEditor=NULL;
                  m_pWebConfMsgBox=NULL;
@@ -145,6 +135,7 @@ namespace vapp {
                  m_bTestThemeMode = false;
                  m_pReplay = NULL;
                  m_pMenuMusic = NULL;
+		 m_updateAutomaticallyLevels = false;
 #if defined(ALLOW_GHOST)
      m_pGhostReplay = NULL;
      m_lastGhostReplay = "";
@@ -184,10 +175,10 @@ namespace vapp {
      m_Renderer.setTheme(&m_theme);
      m_MotoGame.setRenderer(&m_Renderer);
 
-     m_currentThemeName = THEME_DEFAULT_THEMENAME;
-
      m_bPrePlayAnim = true;
      m_bShowEngineCounter = true;
+
+     m_currentPlayingList = NULL;
       }
                  
 #if defined(SUPPORT_WEBACCESS)                 
@@ -197,12 +188,11 @@ namespace vapp {
         virtual void setBeingDownloadedInformation(const std::string &p_information,bool p_bNew = true);
         virtual void readEvents(void);
         
-        virtual bool doesLevelExist(const std::string &LevelID); 
         virtual bool shouldLevelBeUpdated(const std::string &LevelID);
 
         virtual std::string levelPathForUpdate(const std::string &p_LevelId);
         virtual std::string levelMD5Sum(const std::string &LevelID);
-
+	virtual bool doesLevelExist(const std::string &p_LevelId);
 #endif
       
       /* Virtual methods */
@@ -224,7 +214,8 @@ namespace vapp {
       void setState(GameState s);
       void notifyMsg(std::string Msg);      
       void setPrePlayAnim(bool pEnabled);
-      
+      void reloadTheme();
+
       /* Data interface */
       bool isUglyMode() {return m_bUglyMode;}
       bool isTestThemeMode(void) {return m_bTestThemeMode;}
@@ -234,8 +225,6 @@ namespace vapp {
     
       /* Data */
       ReplayList m_ReplayList;                  /* Replay list */
-      std::vector<LevelPack *> m_LevelPacks;    /* Level packs */
-
       bool m_bEnableInitZoom;                   /* true: Perform initial level scroll/zoom */
       bool m_bEnableDeathAnim;                  /* true: Bike falls apart at when dead */
       bool m_bEnableMenuMusic;                  /* true: Play menu music */      
@@ -261,9 +250,6 @@ namespace vapp {
                                                    play this replay */                                                   
       std::string m_ForceProfile;               /* Force this player profile */    
       std::string m_GraphDebugInfoFile;
-      int m_nNumLevels;
-      LevelSrc m_Levels[2048];                  /* Array of levels */
-      
       InputHandler m_InputHandler;              /* The glorious input handler */
       GameState m_State;                        /* Current state */      
       GameState m_StateAfterPlaying;            /* State that should be used later */
@@ -348,10 +334,8 @@ namespace vapp {
       /* Various popups */
       UIMsgBox *m_pQuitMsgBox;
       UIMsgBox *m_pNotifyMsgBox;
-#if defined(SUPPORT_WEBACCESS)
-      UIMsgBox *m_pDownloadMsgBox;
-      UIRect m_DownloadMsgBoxRect;
-#endif            
+      UIMsgBox *m_pInfoMsgBox;
+      UIRect m_InfoMsgBoxRect;
 
       /* Main menu background / title */
       Texture *m_pTitleBL,*m_pTitleBR,*m_pTitleTL,*m_pTitleTR;
@@ -363,7 +347,7 @@ namespace vapp {
       
       /* Main menu buttons and stuff */
       int m_nNumMainMenuButtons;
-      UITabView *m_pLevelTabs;
+      UITabView *m_pLevelPackTabs;
       UIButton *m_pMainMenuButtons[10];
       UIFrame *m_pOptionsWindow,*m_pHelpWindow,*m_pPlayWindow,*m_pReplaysWindow,*m_pLevelPacksWindow;
       UIWindow *m_pMainMenu;
@@ -372,8 +356,8 @@ namespace vapp {
       UIFrame *m_pStatsWindow;
       
       /* LEVEL lists */
-      UILevelList *m_pPlayExternalLevelsList;
-      UILevelList *m_pPlayInternalLevelsList;
+      UILevelList *m_currentPlayingList;
+      UILevelList *m_pAllLevelsList;
 #if defined(SUPPORT_WEBACCESS)
       UILevelList *m_pPlayNewLevelsList;
 #endif
@@ -382,9 +366,17 @@ namespace vapp {
       UIWindow *m_pLevelInfoFrame;
       UIButton *m_pLevelInfoViewReplayButton;      
       UIStatic *m_pBestPlayerText;
+
+      UIWindow *m_pPackLevelInfoFrame;
+      UIButton *m_pPackLevelInfoViewReplayButton;      
+      UIStatic *m_pPackBestPlayerText;
+
       String    m_pLevelToShowOnViewHighscore;
 #endif
 
+      /* if true, don't ask for updating levels */
+      bool m_updateAutomaticallyLevels;
+
       /* In-game PAUSE menu fun */
       UIFrame *m_pPauseMenu;
       int m_nPauseShade;
@@ -420,7 +412,7 @@ namespace vapp {
 
       /* Level pack viewer fun */
       UIFrame *m_pLevelPackViewer;  
-      LevelPack *m_pActiveLevelPack;
+      LevelsPack *m_pActiveLevelPack;
       
       /* Level info viewer fun */
       UIFrame *m_pLevelInfoViewer;      
@@ -432,6 +424,8 @@ namespace vapp {
       /* Config & profiles */
       UserConfig m_Config;
       PlayerData m_Profiles;
+
+      LevelsManager m_levelsManager;
       
       /* Misc settings */
       MenuBackgroundGraphics m_MenuBackgroundGraphics;
@@ -439,7 +433,6 @@ namespace vapp {
       bool m_bRecordReplays;
       float m_fReplayFrameRate;
       float m_fCurrentReplayFrameRate;
-      std::string m_currentThemeName; 
       
       /* Credits */
       Credits *m_pCredits;         
@@ -452,7 +445,6 @@ namespace vapp {
 #if defined(SUPPORT_WEBACCESS) 
       void _UpdateWorldRecord(const std::string &LevelID);
 #endif
-      LevelSrc *_FindLevelByID(std::string ID);
       void _HandleMainMenu(void);  
       void _HandlePauseMenu(void);
       void _HandleJustDeadMenu(void);
@@ -463,7 +455,7 @@ namespace vapp {
       void _HandleProfileEditor(void);
       void _HandleLevelInfoViewer(void);
       void _HandleLevelPackViewer(void);
-      void _CreateLevelLists(UILevelList *pExternalLevels,UILevelList *pInternalLevels);
+      void _CreateLevelLists(UILevelList *pAllLevels, std::string i_packageName);
       void _CreateReplaysList(UIList *pList);
       void _CreateThemesList(UIList *pList);
 #if defined(SUPPORT_WEBACCESS) 
@@ -483,6 +475,9 @@ namespace vapp {
       void _DrawMenuBackground(void); 
       void _DispatchMouseHover(void);                               
       void _InitMenus(void);        
+      void _InitMenus_PlayingMenus(void);
+      void _InitMenus_MainMenu(void);
+      void _InitMenus_Others(void);
       void _ImportOptions(void);
       void _DefaultOptions(void);
       void _SaveOptions(void);
@@ -490,6 +485,9 @@ namespace vapp {
       void _UpdateLevelLists(void);
       void _UpdateReplaysList(void);
       void _UpdateThemesLists(void);
+
+      void _UpdateLevelsLists();
+
 #if defined(SUPPORT_WEBACCESS) 
       void _UpdateRoomsLists(void);
 #endif
@@ -502,16 +500,12 @@ namespace vapp {
       
       int _IsKeyInUse(const std::string &Key);
       
-      void _UpdateLevelPackManager(LevelSrc *pLevelSrc);
-      LevelPack *_FindLevelPackByName(const std::string &Name);
-      std::string _DetermineNextLevel(LevelSrc *pLevelSrc);
-      bool _IsThereANextLevel(LevelSrc *pLevelSrc);
+      std::string _DetermineNextLevel(Level *pLevelSrc);
+      bool _IsThereANextLevel(Level *pLevelSrc);
       
       bool _IsReplayScripted(Replay *p_pReplay);
-      void _RestartLevel();
+      void _RestartLevel(bool i_reloadLevel = false);
   
-      int _LoadLevels(const std::vector<std::string> &LvlFiles);
-    
 #if defined(SUPPORT_WEBACCESS)
       void _InitWebConf(void);
       void _CheckForExtraLevels(void);
@@ -528,11 +522,20 @@ namespace vapp {
 #endif
 
 #if defined(SUPPORT_WEBACCESS)
-      void setLevelInfoFrameBestPlayer(String pLevelID);
+      void setLevelInfoFrameBestPlayer(String pLevelID,
+				       UIWindow *i_pLevelInfoFrame,
+				       UIButton *i_pLevelInfoViewReplayButton,
+				       UIStatic *i_pBestPlayerText
+				       );
       void viewHighscoreOf();
 #endif
 
 #if defined(ALLOW_GHOST) 
+      std::string _getGhostReplayPath_bestOfThePlayer(std::string p_levelId, float &p_time);
+      std::string _getGhostReplayPath_bestOfLocal(std::string p_levelId, float &p_time);
+#if defined(SUPPORT_WEBACCESS)
+      std::string _getGhostReplayPath_bestOfTheRoom(std::string p_levelId, float &p_time);
+#endif
       std::string _getGhostReplayPath(std::string p_levelId,
               GhostSearchStrategy p_strategy);
 #endif
@@ -558,9 +561,11 @@ namespace vapp {
       int _UpdateGameReplaying(void); /* return whether the game state is valid */
       void _PostUpdatePlaying(void);
       void _PostUpdatePause(void);
+      void _PostUpdateMenuDead(void);
       void _PostUpdateJustDead(void);
       void _PostUpdateFinished(void);
 
+      int getNumberOfFinishedLevelsOfPack(LevelsPack *i_pack);
   };
 
 }
