@@ -35,7 +35,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   #include <curl/curl.h>
 #endif
 
-/* Set the follow #define's allow you to simulate slow system */
+#include "helpers/HighPrecisionTimer.h"
+
+/* Set the following #defines to simulate slow systems */
 #define SIMULATE_SLOW_RENDERING     0 /* extra ms to add to rendering */
 #define SIMULATE_SLOW_PHYSICS       0 /* extra ms to add to physics calcs */
 
@@ -48,21 +50,27 @@ namespace vapp {
     /* This function is called by the framework as fast as possible */
     bool bIsPaused = false;
     bool bDrawFPS = false;
+    
+    HighPrecisionTimer::reset();
 
     /* Prepare frame rendering / game update */
-    _PrepareFrame();
+    _PrepareFrame();    
+    HighPrecisionTimer::checkTime("_PrepareFrame");
 
     /* Check some GUI controls */
-    _PreUpdateGUI();
+    _PreUpdateGUI();     
+    HighPrecisionTimer::checkTime("_PreUpdateGUI");
      
     /* Update FPS stuff */
     _UpdateFPSCounter();
+    HighPrecisionTimer::checkTime("_UpdateFPSCounter");
             
     /* What state? */
     switch(m_State) {
       case GS_MENU:
         /* Menu specifics */
         _PreUpdateMenu();
+        HighPrecisionTimer::checkTime("_PreUpdateMenu");
         /* Note the lack of break; the following are done for GS_MENU too */
 
       case GS_LEVEL_INFO_VIEWER:
@@ -73,6 +81,7 @@ namespace vapp {
       case GS_EDIT_PROFILES:
         /* Following is done for all the above states */
         _DrawMainGUI();
+        HighPrecisionTimer::checkTime("_DrawMainGUI");
         
         /* Show frame rate? */
         if(m_bShowFrameRate) bDrawFPS = true;
@@ -84,7 +93,8 @@ namespace vapp {
       case GS_PAUSE:
         bIsPaused = true;
               
-      case GS_JUSTDEAD:
+      case GS_DEADMENU:
+      case GS_DEADJUST:
       case GS_FINISHED:
       case GS_REPLAYING:
       case GS_PREPLAYING:
@@ -98,49 +108,58 @@ namespace vapp {
           /* When did the frame start? */
           double fStartFrameTime = getTime();                    
 
-	        if(m_State == GS_PREPLAYING) {
-	          /* If "preplaying" / "initial-zoom" is enabled, this is where it's done */
-	          statePrestart_step();
-	        } 
-	        else if(m_State == GS_PLAYING || (m_State == GS_JUSTDEAD && m_bEnableDeathAnim)) {
-	          /* When actually playing or when dead and the bike is falling apart, 
-	             a physics update is required */
-	          nPhysSteps = _UpdateGamePlaying();	          
-	        }
+          if(m_State == GS_PREPLAYING) {
+            /* If "preplaying" / "initial-zoom" is enabled, this is where it's done */
+            statePrestart_step();
+            HighPrecisionTimer::checkTime("statePrestart_step");
+          } 
+          else if(m_State == GS_PLAYING || ((m_State == GS_DEADMENU || m_State == GS_DEADJUST) && m_bEnableDeathAnim)) {
+            /* When actually playing or when dead and the bike is falling apart, 
+               a physics update is required */
+            nPhysSteps = _UpdateGamePlaying();            
+            HighPrecisionTimer::checkTime("_UpdateGamePlaying");
+          }
           else if(m_State == GS_REPLAYING) {
             /* When playing back a replay, no physics update is requried - instead
                the game state is streamed out of a binary .rpl file */
             nPhysSteps = _UpdateGameReplaying();
+            HighPrecisionTimer::checkTime("_UpdateGameReplaying");
             bValidGameState = nPhysSteps > 0;
             //printf("%d ",nPhysSteps);
           }
-	
+  
           /* Render */
           if(!isNoGraphics() && bValidGameState) {
             m_Renderer.render(bIsPaused);
-  	  
+            HighPrecisionTimer::checkTime("m_Renderer.render");
+      
             if(m_bShowMiniMap && !m_bCreditsModeActive) {
               if(m_MotoGame.getBikeState()->Dir == DD_LEFT &&
-	               (m_bShowEngineCounter == false || m_State == GS_REPLAYING)) {
+                 (m_bShowEngineCounter == false || m_State == GS_REPLAYING)) {
                 m_Renderer.renderMiniMap(getDispWidth()-150,getDispHeight()-100,150,100);
-	            } 
-	            else {
+                HighPrecisionTimer::checkTime("m_Renderer.renderMiniMap");
+              } 
+              else {
                 m_Renderer.renderMiniMap(0,getDispHeight()-100,150,100);
-	            }
+                HighPrecisionTimer::checkTime("m_Renderer.renderMiniMap");
+              }
             }             
-  	  
-	          if(m_bShowEngineCounter && m_bUglyMode == false && m_State != GS_REPLAYING) {
-	            m_Renderer.renderEngineCounter(getDispWidth()-128,getDispHeight()-128,128,128,
-					                                   m_MotoGame.getBikeEngineSpeed());
-	          } 
+      
+            if(m_bShowEngineCounter && m_bUglyMode == false && m_State != GS_REPLAYING) {
+              m_Renderer.renderEngineCounter(getDispWidth()-128,getDispHeight()-128,128,128,
+                                             m_MotoGame.getBikeEngineSpeed());
+              HighPrecisionTimer::checkTime("m_Renderer.renderEngineCounter");
+            } 
           }
 #if SIMULATE_SLOW_RENDERING
           SDL_Delay(SIMULATE_SLOW_RENDERING);
+          HighPrecisionTimer::checkTime("(dummy)");
 #endif
-	
+  
           /* When actually playing, check if something happened (like dying or finishing) */
           if(m_State == GS_PLAYING) {        
             _PostUpdatePlaying();
+            HighPrecisionTimer::checkTime("_PostUpdatePlaying");
           }
         
           /* When did frame rendering end? */
@@ -157,7 +176,7 @@ namespace vapp {
               nADelay = ((1.0f/m_fCurrentReplayFrameRate - (fEndFrameTime-fStartFrameTime)) * 1000.0f) * 0.5;
             //printf(" { %f }  %d\n",fEndFrameTime-fStartFrameTime,nADelay);            
           }
-          else if ((m_State == GS_FINISHED) || (m_State == GS_JUSTDEAD) || (m_State == GS_PAUSE)) {
+          else if ((m_State == GS_FINISHED) || (m_State == GS_DEADMENU || m_State == GS_DEADJUST) || (m_State == GS_PAUSE)) {
             setFrameDelay(10);
           }
           else {
@@ -185,28 +204,38 @@ namespace vapp {
             drawText(Vector2f(0,100),cBuf,MAKE_COLOR(0,0,0,255),-1);        
             nFrameCnt++;
           }
-        
+
+          HighPrecisionTimer::checkTime("(misc)");
+
           if(m_State == GS_PAUSE) {
             /* Okay, nifty thing. Paused! */
             _PostUpdatePause();
+            HighPrecisionTimer::checkTime("_PostUpdatePause");
           }        
-          else if(m_State == GS_JUSTDEAD) {
+          else if(m_State == GS_DEADJUST) {
             /* Hmm, you're dead and you know it. */
             _PostUpdateJustDead();
-          }        
+            HighPrecisionTimer::checkTime("_PostUpdateJustDead");
+          }
+          else if(m_State == GS_DEADMENU) {
+            /* Hmm, you're dead and you know it. */
+            _PostUpdateMenuDead();
+            HighPrecisionTimer::checkTime("_PostUpdateMenuDead");
+          }
           else if(m_State == GS_FINISHED) {
             /* Hmm, you've won and you know it. */
             _PostUpdateFinished();
+            HighPrecisionTimer::checkTime("_PostUpdateFinished");
           }        
-        
+
           /* Level and player name to draw? */
           if(!m_bCreditsModeActive &&
-            (m_State == GS_JUSTDEAD || m_State == GS_PAUSE || m_State == GS_FINISHED || m_State == GS_REPLAYING) &&
+            (m_State == GS_DEADMENU || m_State == GS_DEADJUST || m_State == GS_PAUSE || m_State == GS_FINISHED || m_State == GS_REPLAYING) &&
             m_MotoGame.getLevelSrc() != NULL) {
             UIFont *v_font = m_Renderer.getMediumFont();
             std::string v_infos;
             
-            v_infos = m_MotoGame.getLevelSrc()->getLevelInfo()->Name;
+            v_infos = m_MotoGame.getLevelSrc()->Name();
 
             if(m_State == GS_REPLAYING && m_pReplay != NULL) {
               v_infos += " (" + std::string(GAMETEXT_BY) + " " + m_pReplay->getPlayerName() + ")";
@@ -217,6 +246,7 @@ namespace vapp {
                 v_infos,
                 MAKE_COLOR(255,255,255,255));
             }
+            HighPrecisionTimer::checkTime("(level and player name)");
           }
          
           /* Context menu? */
@@ -227,19 +257,21 @@ namespace vapp {
           
           /* Draw GUI */
           m_Renderer.getGUI()->paint();        
+          HighPrecisionTimer::checkTime("m_Renderer.getGUI()->paint");
         
           /* Credits? */
           if(m_State == GS_REPLAYING && m_bCreditsModeActive && m_pCredits!=NULL) {
             m_pCredits->render(m_MotoGame.getTime());
+            HighPrecisionTimer::checkTime("m_pCredits->render");
           }
 
           /* Show frame rate */
           if(m_bShowFrameRate) bDrawFPS = true;
-          
+
           break;
         } 
         catch(Exception &e) {
-          setState(GS_MENU);
+    setState(m_StateAfterPlaying);
           notifyMsg(splitText(e.getMsg(), 50));
         }
       }
@@ -252,6 +284,29 @@ namespace vapp {
       drawText(Vector2f(130,0),cTemp);
     }    
     
+    /* Profiling? */
+#if defined(PROFILE_MAIN_LOOP)
+    int nCurY = 60;
+    float fTotal = 0;
+    for(int i=0;i<HighPrecisionTimer::numTimeChecks();i++) {
+      HighPrecisionTimer::TimeCheck *pTc = HighPrecisionTimer::getTimeCheck(i);
+      if(pTc != NULL) {
+        fTotal += pTc->fTime;
+      }
+    }
+    for(int i=0;i<HighPrecisionTimer::numTimeChecks();i++) {
+      char cTemp[256];
+      HighPrecisionTimer::TimeCheck *pTc = HighPrecisionTimer::getTimeCheck(i);
+      if(pTc != NULL) {
+        sprintf(cTemp,"%-20s : %.0f",pTc->cWhere,pTc->fTime);
+        drawText(Vector2f(30,nCurY),cTemp);
+        sprintf(cTemp,"%.0f%%",(pTc->fTime * 100) / fTotal);
+        drawText(Vector2f(350,nCurY),cTemp);
+        nCurY += 16;
+      }
+    }
+#endif   
+    
     /* Draw mouse cursor */
     if(m_bShowCursor)
       _DrawMouseCursor();
@@ -292,8 +347,9 @@ namespace vapp {
 #endif
       case GS_LEVEL_INFO_VIEWER:
       case GS_PAUSE:
-      case GS_JUSTDEAD:
+      case GS_DEADMENU:
       case GS_FINISHED:
+      case GS_LEVELPACK_VIEWER:
         m_bShowCursor = true;
         //SDL_ShowCursor(SDL_ENABLE);
         break;
@@ -310,6 +366,8 @@ namespace vapp {
         }
         
         break;
+      case GS_DEADJUST:
+      break;
     }
   }  
 
@@ -319,7 +377,7 @@ namespace vapp {
       UIMsgBoxButton Button = m_pQuitMsgBox->getClicked();
       if(Button == UI_MSGBOX_YES) {
         if(m_State == GS_PAUSE) {
-          m_GameStats.abortedLevel(m_pPlayer->PlayerName,m_MotoGame.getLevelSrc()->getID(),m_MotoGame.getLevelSrc()->getLevelInfo()->Name,m_MotoGame.getTime()); 
+          m_GameStats.abortedLevel(m_pPlayer->PlayerName,m_MotoGame.getLevelSrc()->Id(),m_MotoGame.getLevelSrc()->Name(),m_MotoGame.getTime()); 
         }
       
         quit();      
@@ -341,11 +399,11 @@ namespace vapp {
     }
 #if defined(SUPPORT_WEBACCESS)
     /* And the download-levels box? */
-    else if(m_pDownloadMsgBox != NULL) {
-      UIMsgBoxButton Button = m_pDownloadMsgBox->getClicked();
+    else if(m_pInfoMsgBox != NULL) {
+      UIMsgBoxButton Button = m_pInfoMsgBox->getClicked();
       if(Button == UI_MSGBOX_YES) {
-        delete m_pDownloadMsgBox;
-        m_pDownloadMsgBox = NULL;
+        delete m_pInfoMsgBox;
+        m_pInfoMsgBox = NULL;
 
         /* Download levels! */
         _DownloadExtraLevels();
@@ -359,8 +417,8 @@ namespace vapp {
         }
       }
       else if(Button == UI_MSGBOX_NO) {
-        delete m_pDownloadMsgBox;
-        m_pDownloadMsgBox = NULL;
+        delete m_pInfoMsgBox;
+        m_pInfoMsgBox = NULL;
       }
     }
 #endif       
@@ -479,12 +537,12 @@ namespace vapp {
     /* Update game until we've catched up with the real time */
     int nPhysSteps = 0;
     do {
-	    if(m_State == GS_PLAYING) {
-	      m_MotoGame.updateLevel( PHYS_STEP_SIZE,NULL,m_pReplay );
-	    } 
-	    else {
-	      m_MotoGame.updateLevel( PHYS_STEP_SIZE,NULL, NULL );
-	    }
+      if(m_State == GS_PLAYING) {
+        m_MotoGame.updateLevel( PHYS_STEP_SIZE,NULL,m_pReplay );
+      } 
+      else {
+        m_MotoGame.updateLevel( PHYS_STEP_SIZE,NULL, NULL );
+      }
       m_fLastPhysTime += PHYS_STEP_SIZE;
       nPhysSteps++;
 
@@ -492,14 +550,14 @@ namespace vapp {
       SDL_Delay(SIMULATE_SLOW_PHYSICS);
 #endif
 
-	    if(m_Config.getBool("LimitFramerate")) {
-	      SDL_Delay(1);
-	    }	    
+      if(m_Config.getBool("LimitFramerate")) {
+        SDL_Delay(1);
+      }     
 
       /* don't do this infinitely, maximum miss 10 frames, then give up */
     } while ((m_fLastPhysTime + PHYS_STEP_SIZE <= getTime()) && (nPhysSteps < 10));
   
-	  m_Renderer.setSpeedMultiplier(nPhysSteps);
+    m_Renderer.setSpeedMultiplier(nPhysSteps);
   
     if(!m_bTimeDemo) {
       /* Never pass this point while being ahead of time, busy wait until it's time */
@@ -525,44 +583,44 @@ namespace vapp {
 #if defined(ALLOW_GHOST)
     /* Read replay state */
     if(m_pGhostReplay != NULL) {
-	    static SerializedBikeState GhostBikeState;
-	    static SerializedBikeState previousGhostBikeState;
+      static SerializedBikeState GhostBikeState;
+      static SerializedBikeState previousGhostBikeState;
       
-	    m_pGhostReplay->peekState(previousGhostBikeState);
-	    if(previousGhostBikeState.fGameTime < m_MotoGame.getTime() && m_pGhostReplay->endOfFile() == false) {
-	      do {
-		      m_pGhostReplay->loadState(GhostBikeState);
-	      } while(GhostBikeState.fGameTime < m_MotoGame.getTime() && m_pGhostReplay->endOfFile() == false);
+      m_pGhostReplay->peekState(previousGhostBikeState);
+      if(previousGhostBikeState.fGameTime < m_MotoGame.getTime() && m_pGhostReplay->endOfFile() == false) {
+        do {
+          m_pGhostReplay->loadState(GhostBikeState);
+        } while(GhostBikeState.fGameTime < m_MotoGame.getTime() && m_pGhostReplay->endOfFile() == false);
 
-	      if(m_nGhostFrame%2 || m_nGhostFrame==1) {
-		      /* NON-INTERPOLATED FRAME */
-		      m_MotoGame.UpdateGhostFromReplay(&GhostBikeState);
-	      } 
-	      else {
-		      /* INTERPOLATED FRAME */
-		      SerializedBikeState ibs;
-		      m_MotoGame.interpolateGameState(&previousGhostBikeState,&GhostBikeState,&ibs,0.5f);
-  	      m_MotoGame.UpdateGhostFromReplay(&ibs);
-	      }
-	      m_nGhostFrame++;
-	    }
-	  }
-#endif	  
+        if(m_nGhostFrame%2 || m_nGhostFrame==1) {
+          /* NON-INTERPOLATED FRAME */
+          m_MotoGame.UpdateGhostFromReplay(&GhostBikeState);
+        } 
+        else {
+          /* INTERPOLATED FRAME */
+          SerializedBikeState ibs;
+          m_MotoGame.interpolateGameState(&previousGhostBikeState,&GhostBikeState,&ibs,0.5f);
+          m_MotoGame.UpdateGhostFromReplay(&ibs);
+        }
+        m_nGhostFrame++;
+      }
+    }
+#endif    
 
-	  if(m_State == GS_PLAYING) {
-	    /* We'd like to serialize the game state 25 times per second for the replay */
-	    if(getRealTime() - m_fLastStateSerializationTime >= 1.0f/m_fReplayFrameRate) {
-	      m_fLastStateSerializationTime = getRealTime();
+    if(m_State == GS_PLAYING) {
+      /* We'd like to serialize the game state 25 times per second for the replay */
+      if(getRealTime() - m_fLastStateSerializationTime >= 1.0f/m_fReplayFrameRate) {
+        m_fLastStateSerializationTime = getRealTime();
         
-	      /* Get it */
-	      SerializedBikeState BikeState;
-	      m_MotoGame.getSerializedBikeState(&BikeState);
-	      if(m_pReplay != NULL)
-		      m_pReplay->storeState(BikeState);              
-	    }
-	  }
-	  
-	  return nPhysSteps;
+        /* Get it */
+        SerializedBikeState BikeState;
+        m_MotoGame.getSerializedBikeState(&BikeState);
+        if(m_pReplay != NULL)
+          m_pReplay->storeState(BikeState);              
+      }
+    }
+    
+    return nPhysSteps;
   }  
 
   int GameApp::_UpdateGameReplaying(void) {
@@ -601,8 +659,8 @@ namespace vapp {
       /* Even frame number: Read the next state */
       if(m_nFrame%2 || m_nFrame==1) {       
         /* REAL NON-INTERPOLATED FRAME */
-	      if(m_pReplay->endOfFile() == false) {
-		      m_pReplay->loadState(BikeState);
+        if(m_pReplay->endOfFile() == false) {
+          m_pReplay->loadState(BikeState);
         
           /* Update game */
           m_MotoGame.updateLevel( 1/m_pReplay->getFrameRate(),&BikeState,m_pReplay ); 
@@ -623,11 +681,11 @@ namespace vapp {
       else {                          
         /* INTERPOLATED FRAME */
         SerializedBikeState NextBikeState,ibs;
-  	    
-	      if(m_pReplay->endOfFile() == false) {
-		      m_pReplay->peekState(NextBikeState);
-		      /* Nice. Interpolate the states! */
-		      m_MotoGame.interpolateGameState(&BikeState,&NextBikeState,&ibs,0.5f);
+        
+        if(m_pReplay->endOfFile() == false) {
+          m_pReplay->peekState(NextBikeState);
+          /* Nice. Interpolate the states! */
+          m_MotoGame.interpolateGameState(&BikeState,&NextBikeState,&ibs,0.5f);
 
           /* Update game */
           //m_MotoGame.updateLevel( PHYS_STEP_SIZE,&ibs,m_pReplay );                 
@@ -647,12 +705,12 @@ namespace vapp {
     }
     else return 0; /* something went wrong */
   
-    if(m_pReplay->getSpeed() < 0) {
-      m_Renderer.clearAllParticles();
-      m_Renderer.skipBackTime(100000);            
-    }
+    //if(m_pReplay->getSpeed() < 0) {
+    //m_Renderer.clearAllParticles();
+    //m_Renderer.skipBackTime(100000);            
+    //}
   
-	  m_Renderer.setSpeedMultiplier(nPhysSteps);    
+    m_Renderer.setSpeedMultiplier(nPhysSteps);    
 
     return nPhysSteps;
   }
@@ -661,16 +719,17 @@ namespace vapp {
     /* News? */
     if(m_MotoGame.isDead()) {
       /* You're dead maan! */
-      setState(GS_JUSTDEAD);
+      setState(GS_DEADJUST);
     }
     else if(m_MotoGame.isFinished()) {
       /* You're done maaaan! :D */
       std::string TimeStamp = getTimeStamp();
       m_Profiles.addFinishTime(m_pPlayer->PlayerName,"",
-                              m_MotoGame.getLevelSrc()->getID(),m_MotoGame.getFinishTime(),TimeStamp); 
-      _MakeBestTimesWindow(m_pBestTimes,m_pPlayer->PlayerName,m_MotoGame.getLevelSrc()->getID(),
+                              m_MotoGame.getLevelSrc()->Id(),m_MotoGame.getFinishTime(),TimeStamp); 
+      _MakeBestTimesWindow(m_pBestTimes,m_pPlayer->PlayerName,m_MotoGame.getLevelSrc()->Id(),
                           m_MotoGame.getFinishTime(),TimeStamp);
-      _UpdateLevelLists();
+
+      _UpdateLevelsLists();     
       setState(GS_FINISHED);
     }
   }
@@ -693,6 +752,13 @@ namespace vapp {
       if(m_nJustDeadShade < 150) m_nJustDeadShade+=8;
       drawBox(Vector2f(0,0),Vector2f(getDispWidth(),getDispHeight()),0,MAKE_COLOR(0,0,0,m_nJustDeadShade));     
     }
+  }
+
+  void GameApp::_PostUpdateMenuDead(void) {
+    if(!m_bUglyMode) {
+      if(m_nJustDeadShade < 150) m_nJustDeadShade+=8;
+      drawBox(Vector2f(0,0),Vector2f(getDispWidth(),getDispHeight()),0,MAKE_COLOR(0,0,0,m_nJustDeadShade));     
+    }
     
     /* Update mouse stuff */
     _DispatchMouseHover();
