@@ -115,12 +115,7 @@ namespace vapp {
               &m_ProxySettings
 #endif
               );
-    try {
-      m_theme.load(m_themeChoicer->getFileName(getConfigThemeName(m_themeChoicer)));
-    } catch(Exception &e) {
-      /* unable to load the theme, load the default one */
-      m_theme.load(m_themeChoicer->getFileName(THEME_DEFAULT_THEMENAME));
-    }
+    reloadTheme();
 
     /* Profiles */
     Log("Loading profiles...");
@@ -145,41 +140,7 @@ namespace vapp {
     m_GameStats.loadXML("stats.xml");
     if(m_pPlayer != NULL)
       m_GameStats.xmotoStarted(m_pPlayer->PlayerName);
-    
-    /* Update replays */
-    m_ReplayList.initFromDir();
-    
-    /* List replays? */  
-    if(m_bListReplays) {
-      std::vector<ReplayInfo *> *Replays = m_ReplayList.findReplays();
-      printf("\nReplay                    Level                     Player\n");
-      printf("-----------------------------------------------------------------------\n");
-      for(int i=0;i<Replays->size();i++) {
-        std::string LevelDesc;
-        
-        if((*Replays)[i]->Level.length() == 6 &&
-           (*Replays)[i]->Level[0] == '_' && (*Replays)[i]->Level[1] == 'i' &&
-           (*Replays)[i]->Level[2] == 'L' && (*Replays)[i]->Level[5] == '_') {
-          int nNum;
-          sscanf((*Replays)[i]->Level.c_str(),"_iL%d_",&nNum);
-          char cBuf[256];
-          sprintf(cBuf,"#%d",nNum+1);
-          LevelDesc = cBuf;
-        }
-        else LevelDesc = (*Replays)[i]->Level;
-      
-        printf("%-25s %-25s %-25s\n",
-               (*Replays)[i]->Name.c_str(),
-               LevelDesc.c_str(),
-               (*Replays)[i]->Player.c_str());
-      }
-      if(Replays->empty()) printf("(none)\n");
-      delete Replays;
-      quit();
-      return;
-    }
-
-    
+   
     /* Init sound system */
     if(!isNoGraphics()) {
       Log("Initializing sound system...");
@@ -212,11 +173,52 @@ namespace vapp {
       pSprite = m_theme.getSprite(SPRITE_TYPE_UI, "Loading");
 
       if(pSprite != NULL) {
-  pLoadingScreen = pSprite->getTexture(false, true);
+	pLoadingScreen = pSprite->getTexture(false, true);
       }
+    }
 
+    /* Update replays */
+    _UpdateLoadingScreen((1.0f/9.0f) * 0,pLoadingScreen,GAMETEXT_LOADINGREPLAYS);
+    
+    try {
+      m_ReplayList.initFromCache();
+    } catch(Exception &e) {
+      m_ReplayList.initFromDir();
+    }    
+    
+    /* List replays? */  
+    if(m_bListReplays) {
+      std::vector<ReplayInfo *> *Replays = m_ReplayList.findReplays();
+      printf("\nReplay                    Level                     Player\n");
+      printf("-----------------------------------------------------------------------\n");
+      for(int i=0;i<Replays->size();i++) {
+	std::string LevelDesc;
+	
+	if((*Replays)[i]->Level.length() == 6 &&
+	   (*Replays)[i]->Level[0] == '_' && (*Replays)[i]->Level[1] == 'i' &&
+	   (*Replays)[i]->Level[2] == 'L' && (*Replays)[i]->Level[5] == '_') {
+	  int nNum;
+	  sscanf((*Replays)[i]->Level.c_str(),"_iL%d_",&nNum);
+	  char cBuf[256];
+	  sprintf(cBuf,"#%d",nNum+1);
+	  LevelDesc = cBuf;
+	}
+	else LevelDesc = (*Replays)[i]->Level;
+	
+	printf("%-25s %-25s %-25s\n",
+	       (*Replays)[i]->Name.c_str(),
+	       LevelDesc.c_str(),
+	       (*Replays)[i]->Player.c_str());
+      }
+	if(Replays->empty()) printf("(none)\n");
+      delete Replays;
+      quit();
+      return;
+    }
+    
+    if(!isNoGraphics()) {  
       _UpdateLoadingScreen((1.0f/9.0f) * 0,pLoadingScreen,GAMETEXT_LOADINGSOUNDS);
-
+      
       if(Sound::isEnabled()) {
         /* Load sounds */
         Sound::loadSample("Sounds/NewHighscore.ogg");
@@ -283,7 +285,7 @@ namespace vapp {
       m_pCursor = NULL;
       pSprite = m_theme.getSprite(SPRITE_TYPE_UI, "Cursor");
       if(pSprite != NULL) {
-	      m_pCursor = pSprite->getTexture(false, true, FM_LINEAR);
+        m_pCursor = pSprite->getTexture(false, true, FM_LINEAR);
       }
 
 #if defined(SUPPORT_WEBACCESS)  
@@ -298,36 +300,25 @@ namespace vapp {
     }
     
     /* Test level cache directory */
-    std::string LCachePath = FS::getUserDir() + std::string("/LCache");
-    if(m_bEnableLevelCache && !FS::isDir(LCachePath)) {
-      m_bEnableLevelCache = false;
-      Log("** Warning ** : Level cache directory not found, forcing caching off!");
-    }
+    LevelsManager::checkPrerequires(m_bEnableLevelCache);
     
     /* Should we clean the level cache? (can also be done when disabled) */
     if(m_bCleanCache) {
-      /* Find all .blv-files in the directory */
-      std::vector<std::string> BlvFiles = FS::findPhysFiles("LCache/*.blv");
-      Log("Trying to clean %d files from level cache...",BlvFiles.size());
-      int nNumDeleted = 0;
-      for(int i=0;i<BlvFiles.size();i++) {
-        if(FS::deleteFile(BlvFiles[i]))
-          nNumDeleted++;
-      }
-      Log(" %d file%s deleted succesfully",nNumDeleted,nNumDeleted==1?"":"s");
+      LevelsManager::cleanCache();
     }
      
-    /* Find all .lvl files in the level dir and load them */    
-    m_nNumLevels = 0;
-    std::vector<std::string> LvlFiles = FS::findPhysFiles("Levels/*.lvl",true);
-    int nNumCached = _LoadLevels(LvlFiles);
+    try {
+      m_levelsManager.loadLevelsFromIndex();
+    } catch(Exception &e) {
+      Log(std::string("Unable to load levels from index:\n" + e.getMsg()).c_str());
+      m_levelsManager.reloadLevelsFromFiles(m_bEnableLevelCache);
+    }
     
     /* -listlevels? */
     if(m_bListLevels) {
-      for(int i=0;i<m_nNumLevels;i++) {          
-        printf("%-25s %-25s %-25s\n",FS::getFileBaseName(m_Levels[i].getFileName()).c_str(),m_Levels[i].getID().c_str(),m_Levels[i].getLevelInfo()->Name.c_str());
-      }
+      m_levelsManager.printLevelsList();
     }
+
     _UpdateLoadingScreen((1.0f/9.0f) * 5,pLoadingScreen,GAMETEXT_INITRENDERER);
     
     if(m_bListLevels) {
@@ -335,9 +326,6 @@ namespace vapp {
       return;
     }
     
-    Log(" %d level%s loaded (%d from cache)",m_nNumLevels,m_nNumLevels==1?"":"s",nNumCached);
-    Log(" %d level pack%s",m_LevelPacks.size(),m_LevelPacks.size()==1?"":"s");
-
     #if defined(SUPPORT_WEBACCESS)    
       /* Fetch highscores from web? */
       if(m_pWebHighscores != NULL) delete m_pWebHighscores;
@@ -381,7 +369,7 @@ namespace vapp {
       _InitMenus();    
       _UpdateLoadingScreen((1.0f/9.0f) * 8,pLoadingScreen,GAMETEXT_UPDATINGLEVELS);
 
-      _UpdateLevelLists();
+      _UpdateLevelsLists();
       _UpdateLoadingScreen((1.0f/9.0f) * 9,pLoadingScreen,GAMETEXT_INITINPUT);      
       
       /* Init input system */
@@ -422,53 +410,7 @@ namespace vapp {
       }
     }            
   }
-  
-  /*===========================================================================
-  Load some levels...
-  ===========================================================================*/
-  int GameApp::_LoadLevels(const std::vector<std::string> &LvlFiles) {
-    int nNumCached = 0;
-  
-    for(int i=0;i<LvlFiles.size();i++) {    
-      int j = m_nNumLevels;
-      if(j >= 2048) {
-        Log("** Warning ** : Too many levels.");
-        break;
-      }
     
-      bool bCached = false;
-      try {
-        // Load the level
-        m_Levels[j].setFileName( LvlFiles[i] );
-        bCached = m_Levels[j].load(m_bEnableLevelCache);
-        
-        // Check for ID conflict
-        for(int k=0;k<m_nNumLevels;k++) {
-          if(m_Levels[k].getID() == m_Levels[j].getID()) {
-            /* Conflict! */
-            Log("** Warning ** : More than one level with ID '%s'!",m_Levels[k].getID().c_str());
-            Log("                (%s)",m_Levels[j].getFileName().c_str());
-            Log("                (%s)",m_Levels[k].getFileName().c_str());
-            if(bCached) Log("                (cached)");
-            throw Exception("Duplicate level ID");
-          }
-        }
-        
-        if (bCached) ++nNumCached;
-        ++m_nNumLevels;
-        
-        /* Update level pack manager */
-        _UpdateLevelPackManager(&m_Levels[j]);
-      
-      } catch(Exception &e) {
-        Log("** Warning ** : Problem loading '%s' (%s)",
-          LvlFiles[i].c_str(),e.getMsg().c_str());            
-      }
-    }
-      
-    return nNumCached;
-  }
-  
   /*===========================================================================
   Shutdown game
   ===========================================================================*/
@@ -487,11 +429,7 @@ namespace vapp {
     if(m_pCredits != NULL)
       delete m_pCredits;
   
-    for(int i=0;i<m_LevelPacks.size();i++) {
-      delete m_LevelPacks[i];
-    }
-    m_LevelPacks.clear();
-    
+    m_levelsManager.saveXml();
     m_GameStats.saveXML("stats.xml");
       
     if(!isNoGraphics()) {
@@ -520,6 +458,7 @@ namespace vapp {
     Sound::uninit();
 
     m_Config.saveFile();
+
     m_Profiles.saveFile();
 
     if(!isNoGraphics()) {
@@ -546,12 +485,20 @@ namespace vapp {
           m_PlaySpecificLevel = UserArgs[i+1];
           
           /* If it is a plain number, it's for a internal level */
-          int nNum = atoi(m_PlaySpecificLevel.c_str());
-          if(nNum > 0) {
-            char cBuf[256];
-            sprintf(cBuf,"_iL%02d_",nNum-1);
-            m_PlaySpecificLevel = cBuf;
-          }
+    bool v_isANumber =  true;
+    for(int i=0; i<m_PlaySpecificLevel.length(); i++) {
+      if(m_PlaySpecificLevel[i] < '0' || m_PlaySpecificLevel[i] > '9') {
+        v_isANumber = false;
+      }
+    }
+    if(v_isANumber) {
+      int nNum = atoi(m_PlaySpecificLevel.c_str());
+      if(nNum > 0) {
+        char cBuf[256];
+        sprintf(cBuf,"_iL%02d_",nNum-1);
+        m_PlaySpecificLevel = cBuf;
+      }
+    }
         }
         else
           throw SyntaxError("no level specified");        
