@@ -38,8 +38,10 @@ Central place to keep many in-game text strings
 #define GAMETEXT_44KHZ                _("44 kHz")
 #define GAMETEXT_8BIT                 _("8-bit")
 #define GAMETEXT_ABORT                _("Abort Playing")
+#define GAMETEXT_ADDTOFAVORITE       _("Add to favorite")
 #define GAMETEXT_ACTION               _("Action")
 #define GAMETEXT_ALL                  _("All (on this computer)")
+#define GAMETEXT_ALL_LEVELS           _("All levels")
 #define GAMETEXT_ALLOWINTERNETCONN    _("Do you want to allow X-Moto connecting\n" \
                                         "to the Internet to look for more levels\n" \
                                         "and best times of other players?")
@@ -101,6 +103,7 @@ Central place to keep many in-game text strings
                                         "Website Localization:Felix Schl;" \
                                         ":Nicolas Adenis-Lamarre;" \
                                         ":Trullo;" \
+                                        ":Afaland;" \
                                         ":Jj;" \
                                         ":Vertigo;" \
                                         ":Pol Vinogradov;" \
@@ -132,6 +135,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_DELETEPLAYERMESSAGE  _("Do you really want to delete player?")
 #define GAMETEXT_DELETEREPLAYMESSAGE  _("Do you really want to delete replay?")
 #define GAMETEXT_DELETE               _("Delete")
+#define GAMETEXT_DELETEFROMFAVORITE  _("Delete from favorite")
 #define GAMETEXT_DELETEPROFILE        _("Delete")
 #define GAMETEXT_DESCRIPTION          _("Description")
 #define GAMETEXT_DISPLAYGHOSTTIMEDIFF _("Display Ghost time difference")
@@ -143,7 +147,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_DLLEVELS             _("Downloading extra levels...\nPress ESC to abort.")
 #define GAMETEXT_DLLEVELSCHECK        _("Checking for new levels...")
 #define GAMETEXT_DLROOMSLISTCHECK     _("Checking for existing rooms...")
-#define GAMETEXT_DLTHEME              _("Getting the theme\nPress ESC to abort.")
+#define GAMETEXT_DLTHEME              _("Downloading theme data required by new levels...\nPress ESC to abort.")
 #define GAMETEXT_DLTHEMESLISTCHECK    _("Checking for new themes...")
 #define GAMETEXT_DOWNLOADLEVELS       _("Get More Levels!")
 #define GAMETEXT_DRIVE                _("Drive")
@@ -212,6 +216,8 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_INITZOOM             _("View Level Initially")
 #define GAMETEXT_JOYSTICK             _("Joystick")
 #define GAMETEXT_JUSTDEAD             _("Oops!")
+#define GAMETEXT_JUSTDEAD_RESTART     _("Press ENTER to try again")
+#define GAMETEXT_JUSTDEAD_DISPLAYMENU _("Press ESC to display the menu")
 #define GAMETEXT_KEY                  _("Key")
 #define GAMETEXT_KEYBOARD             _("Keyboard")
 #define GAMETEXT_LEVEL                _("Level")
@@ -225,6 +231,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_LISTALL              _("List All")
 #define GAMETEXT_LOADINGLEVELS        _("Loading levels...")
 #define GAMETEXT_LOADINGMENUGRAPHICS  _("Loading menu graphics...")
+#define GAMETEXT_LOADINGREPLAYS       _("Loading replays...")
 #define GAMETEXT_LOADINGSOUNDS        _("Loading sounds...")
 #define GAMETEXT_LOADINGTEXTURES      _("Loading textures...")
 #define GAMETEXT_LOGIN                _("Login")
@@ -278,12 +285,14 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_PROXYCONFIG          _("Configure Proxy...")
 #define GAMETEXT_QUIT                 _("Quit Game")
 #define GAMETEXT_QUITMESSAGE          _("Do you really want to quit?")
+#define GAMETEXT_RELOADINGLEVELS      _("Reloading levels...")
+#define GAMETEXT_RELOADINGREPLAYS     _("Reloading replays...")
 #define GAMETEXT_REPLAY               _("Replay")
-#define GAMETEXT_REPLAYHELPTEXT(current_speed) _("Stop[esc] ||[space]  << >>[right/left keys]  < >[up/down keys]   Speed:") + current_speed + "x"
-#define GAMETEXT_REPLAYHELPTEXTNOREWIND(current_speed) _("Stop[esc] ||[space] >>[left key] < >[up/down keys]   Speed:") + current_speed + "x"
+#define GAMETEXT_REPLAYHELPTEXT(current_speed) _("Stop[esc] ||[space]  << >>[left/right keys]  < >[up/down keys]   Speed:") + current_speed + "x"
+#define GAMETEXT_REPLAYHELPTEXTNOREWIND(current_speed) _("Stop[esc] ||[space] >>[right key] < >[up/down keys]   Speed:") + current_speed + "x"
   // + "a" + "X"
 #define GAMETEXT_REPLAYNOTFOUND       _("Replay '%s' can't be played!")
-#define GAMETEXT_REPLAYS              _("View Replays")
+#define GAMETEXT_REPLAYS              _("Replays")
 #define GAMETEXT_RESTART              _("Restart This Level")
 #define GAMETEXT_RESUME               _("Resume Playing")
 #define GAMETEXT_ROOM                 _("Room")
@@ -310,6 +319,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_TRYAGAIN             _("Try This Level Again")
 #define GAMETEXT_TUTORIAL             _("Tutorial")
 #define GAMETEXT_UNKNOWNLEVEL         _("Unknown")
+#define GAMETEXT_UNPACKED_LEVELS_PACK _("Unpacked levels")
 #define GAMETEXT_UNUPDATABLETHEMEONWEB _("Can't update this theme !\nThe theme is not avaible on the web\nor your theme list is not up to date")
 #define GAMETEXT_UPDATE               _("Update")
 #define GAMETEXT_UPDATEHIGHSCORES     _("Check WWW")
@@ -343,6 +353,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_XMOTOLEVELSTATS      _("%d plays, %d deaths, %d finishes, and %d restarts")
 #define GAMETEXT_XSECONDS             _("%d seconds")
 #define GAMETEXT_YES                  _("Yes")
+#define GAMETEXT_YES_FOR_ALL          _("Yes to all")
 #define GAMETEXT_ZOOMIN  	      _("Zoom in")
 #define GAMETEXT_ZOOMINIT 	      _("Reinitialize zoom")
 #define GAMETEXT_ZOOMOUT 	      _("Zoom out")
@@ -361,6 +372,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_TRY_LEVEL_AGAIN _("Try this level again")
 #define CONTEXTHELP_BUILT_IN_AND_EXTERNALS _("Built-in and stand-alone external levels")
 #define CONTEXTHELP_LEVEL_PACKS _("Levels grouped together in level packs")
+#define CONTEXTHELP_LEVELS _("Browse levels avaiable to you")
 #define CONTEXTHELP_REPLAY_LIST _("View list of recorded replays")
 #define CONTEXTHELP_OPTIONS _("Configure X-Moto preferences")
 #define CONTEXTHELP_HELP _("Instructions of how to play X-Moto")
@@ -458,5 +470,23 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_DEATHANIM _("Enable animation of bike falling apart when dead")
 #define CONTEXTHELP_INITZOOM _("Automatically scroll over the level before starting playing it")
 #define CONTEXTHELP_CREDITS _("View the X-Moto credits")
+#define CONTEXTHELP_REPLAYCOL _("Name of replay")
+#define CONTEXTHELP_REPLAYLEVELCOL _("Level played in replay")
+#define CONTEXTHELP_REPLAYPLAYERCOL _("Player who recorded the replay")
+#define CONTEXTHELP_SCREENRES _("Click to select screen resolution")
+#define CONTEXTHELP_LEVELPACKNUMLEVELS _("Completed levels / total number of levels in pack")
+#define CONTEXTHELP_LEVELPACK _("Name of level pack")
+#define CONTEXTHELP_ADDTOFAVORITE _("Add the level to the favorite levels list")
+#define CONTEXTHELP_DELETEFROMFAVORITE _("Delete the level from the favorite levels list")
+
+#define VPACKAGENAME_LEVELS_WITH_NO_HIGHSCORE   _("Levels with no highscore")
+#define VPACKAGENAME_RANDOM_LEVELS              _("Random levels")
+#define VPACKAGENAME_INCOMPLETED_LEVELS         _("Levels you have not completed")
+#define VPACKAGENAME_YOU_HAVE_NOT_THE_HIGHSCORE _("You're not the highscore holder")
+#define VPACKAGENAME_ALL_LEVELS                 _("All levels")
+#define VPACKAGENAME_NEW_LEVELS                 _("New levels")
+#define VPACKAGENAME_UPDATED_LEVELS             _("Updated levels")
+#define VPACKAGENAME_MOST_PLAYED_LEVELS         _("Most played levels")
+#define VPACKAGENAME_FAVORITE_LEVELS            _("Favorite levels")
 
 #endif
