@@ -54,7 +54,7 @@ namespace vapp {
   ===========================================================================*/
   enum InputEventType {
     INPUT_KEY_DOWN,
-    INPUT_KEY_UP,    
+    INPUT_KEY_UP    
   };
   
   struct InputKeyMap {
@@ -112,7 +112,7 @@ namespace vapp {
       
       void resetScriptKeyHooks(void) {m_nNumScriptKeyHooks = 0;}
       void addScriptKeyHook(MotoGame *pGame,const std::string &KeyName,const std::string &FuncName);
-      
+
       std::string getKeyByAction(const std::string &Action);
     
     private:
@@ -171,7 +171,7 @@ namespace vapp {
       void _SetDefaultConfigToUnsetKeys();
   };
   
-};
+}
 
 
 #endif
