@@ -24,7 +24,7 @@
  */
 #include "VFileIO.h"
 #include "PlayerData.h"
-#include "arch/SwapEndian.h"
+#include "helpers/SwapEndian.h"
 
 namespace vapp {
 
@@ -156,9 +156,9 @@ namespace vapp {
     FileHandle *pfh = FS::openOFile("players.bin");
     if(pfh == NULL) { 
       Log("** Warning ** : failed to save 'players.bin', all new stats is lost");
-      return;	    
+      return;     
     }
-	  
+    
     /* Write */
     FS::writeShort_LE(pfh,0x12);
     FS::writeInt_LE(pfh,m_Profiles.size());
@@ -166,29 +166,29 @@ namespace vapp {
       FS::writeString(pfh,m_Profiles[i]->PlayerName);
       FS::writeInt_LE(pfh,m_Profiles[i]->Completed.size());
       FS::writeInt_LE(pfh,m_Profiles[i]->Skipped.size());
-	    
+      
       for(int j=0;j<m_Profiles[i]->Completed.size();j++)
-	FS::writeString(pfh,m_Profiles[i]->Completed[j]);	      
+  FS::writeString(pfh,m_Profiles[i]->Completed[j]);       
 
       for(int j=0;j<m_Profiles[i]->Skipped.size();j++)
-	FS::writeString(pfh,m_Profiles[i]->Skipped[j]);	      
+  FS::writeString(pfh,m_Profiles[i]->Skipped[j]);       
         
       for(int j=0;j<m_Profiles[i]->LevelStats.size();j++) {
-	for(int k=0;k<m_Profiles[i]->LevelStats[j]->nNumBestTimes;k++) {
-	  FS::writeString(pfh,m_Profiles[i]->LevelStats[j]->LevelID);
-	  FS::writeString(pfh,m_Profiles[i]->LevelStats[j]->BestTimes[k].Replay);
-	  FS::writeString(pfh,m_Profiles[i]->LevelStats[j]->BestTimes[k].TimeStamp);
-	  FS::writeFloat_LE(pfh,m_Profiles[i]->LevelStats[j]->BestTimes[k].fFinishTime);
-	}
+  for(int k=0;k<m_Profiles[i]->LevelStats[j]->nNumBestTimes;k++) {
+    FS::writeString(pfh,m_Profiles[i]->LevelStats[j]->LevelID);
+    FS::writeString(pfh,m_Profiles[i]->LevelStats[j]->BestTimes[k].Replay);
+    FS::writeString(pfh,m_Profiles[i]->LevelStats[j]->BestTimes[k].TimeStamp);
+    FS::writeFloat_LE(pfh,m_Profiles[i]->LevelStats[j]->BestTimes[k].fFinishTime);
+  }
       }
       
       FS::writeByte(pfh,0);
     }
-	  
+    
     /* Clean */
-    FS::closeFile(pfh);	  
+    FS::closeFile(pfh);   
   }
-	
+  
   /*===========================================================================
     Creation and destruction of profiles
     ===========================================================================*/
@@ -197,9 +197,9 @@ namespace vapp {
       Log("** Warning ** : player profile '%s' already in use",PlayerName.c_str());
       return NULL;
     }
-	
+  
     PlayerProfile *pProfile = new PlayerProfile;
-    pProfile->PlayerName = PlayerName;	  
+    pProfile->PlayerName = PlayerName;    
     m_Profiles.push_back(pProfile);
     return pProfile;
   }
@@ -207,40 +207,40 @@ namespace vapp {
   void PlayerData::destroyProfile(std::string PlayerName) {
     for(int i=0;i<m_Profiles.size();i++) {
       if(m_Profiles[i]->PlayerName == PlayerName) {
-	for(int j=0;j<m_Profiles[i]->LevelStats.size();j++)
-	  delete m_Profiles[i]->LevelStats[j];
-	    
-	delete m_Profiles[i];
-	m_Profiles.erase(m_Profiles.begin() + i);
-	return;
+  for(int j=0;j<m_Profiles[i]->LevelStats.size();j++)
+    delete m_Profiles[i]->LevelStats[j];
+      
+  delete m_Profiles[i];
+  m_Profiles.erase(m_Profiles.begin() + i);
+  return;
       }
     }
     Log("** Warning ** : attempt to destroy unknown player profile '%s'",PlayerName.c_str());
   }
-	
+  
   /*===========================================================================
     Information about levels
     ===========================================================================*/
   bool PlayerData::isLevelCompleted(std::string PlayerName,std::string LevelID) {
     PlayerProfile *pPlayer = getProfile(PlayerName);
     if(pPlayer == NULL) return false;
-	  
+    
     for(int i=0;i<pPlayer->Completed.size();i++)
       if(pPlayer->Completed[i] == LevelID) return true;
-	  
+    
     return false;
   }
-	
+  
   bool PlayerData::isLevelSkipped(std::string PlayerName,std::string LevelID) {
     PlayerProfile *pPlayer = getProfile(PlayerName);
     if(pPlayer == NULL) return false;
-	  
+    
     for(int i=0;i<pPlayer->Skipped.size();i++)
       if(pPlayer->Skipped[i] == LevelID) return true;
-	  
+    
     return false;
   }
-	
+  
   void PlayerData::completeLevel(std::string PlayerName,std::string LevelID) {
     PlayerProfile *pPlayer = getProfile(PlayerName);
     if(pPlayer == NULL) return;
@@ -248,23 +248,23 @@ namespace vapp {
     /* If skipped, unskip it */
     for(int i=0;i<pPlayer->Skipped.size();i++) {
       if(pPlayer->Skipped[i] == LevelID) {
-	pPlayer->Skipped.erase(pPlayer->Skipped.begin() + i);
-	break;
+  pPlayer->Skipped.erase(pPlayer->Skipped.begin() + i);
+  break;
       }
     }
-	  
+    
     if(!isLevelCompleted(PlayerName,LevelID)) {
       pPlayer->Completed.push_back(LevelID);
     }
   }
-	
+  
   void PlayerData::skipLevel(std::string PlayerName,std::string LevelID) {
     if(!isLevelCompleted(PlayerName,LevelID) && !isLevelSkipped(PlayerName,LevelID)) {
       PlayerProfile *pPlayer = getProfile(PlayerName);
-      if(pPlayer != NULL) pPlayer->Skipped.push_back(LevelID);	    
-    }	  
+      if(pPlayer != NULL) pPlayer->Skipped.push_back(LevelID);      
+    }   
   }
-	
+  
   /*===========================================================================
     Check if a level is internal
     ===========================================================================*/
@@ -274,36 +274,36 @@ namespace vapp {
     int j = 0;
     while(pcInternals[j] != NULL) {
       if(!strcmp(pcInternals[j],LevelID.c_str())) {
-	return true;
+  return true;
       }
       j++;
     }
     return false;
   }
-	
+  
   /*===========================================================================
     Merge finish time
     ===========================================================================*/
   void PlayerData::addFinishTime(std::string PlayerName,
-				 std::string Replay,
-				 std::string LevelID,
-				 float fTime,
-				 std::string TimeStamp) {
+         std::string Replay,
+         std::string LevelID,
+         float fTime,
+         std::string TimeStamp) {
 
     PlayerProfile *pPlayer = getProfile(PlayerName);
     if(pPlayer == NULL) return;
-	  
+    
     /* Look for this level */
     PlayerLevelStats *pStats = NULL; 
-	  
+    
     for(int i=0;i<pPlayer->LevelStats.size();i++) {
       if(pPlayer->LevelStats[i]->LevelID == LevelID) 
-	pStats = pPlayer->LevelStats[i];
-    }	  
-	  
+  pStats = pPlayer->LevelStats[i];
+    }   
+    
     /* Is this internal? */
     completeLevel(PlayerName,LevelID);
-	  
+    
     /* Not there? Then add it */
     if(pStats == NULL) {
       pStats = new PlayerLevelStats;
@@ -311,10 +311,10 @@ namespace vapp {
       pStats->nNumBestTimes = 0;
       pPlayer->LevelStats.push_back(pStats);
     }
-	  
+    
     /* If less than 10 entries, simply add this and we're done */
     if(pStats->nNumBestTimes < 10) {
-      pStats->BestTimes[pStats->nNumBestTimes].fFinishTime = fTime;	    
+      pStats->BestTimes[pStats->nNumBestTimes].fFinishTime = fTime;     
       pStats->BestTimes[pStats->nNumBestTimes].PlayerName = PlayerName;
       pStats->BestTimes[pStats->nNumBestTimes].Replay = Replay;
       pStats->BestTimes[pStats->nNumBestTimes].TimeStamp = TimeStamp;
@@ -323,23 +323,23 @@ namespace vapp {
     else {
       /* Find poorest time in list */
       int nBadTime=-1;
-	    
+      
       for(int i=0;i<pStats->nNumBestTimes;i++) {
-	if(nBadTime<0 || pStats->BestTimes[i].fFinishTime > pStats->BestTimes[nBadTime].fFinishTime)
-	  nBadTime = i;
+  if(nBadTime<0 || pStats->BestTimes[i].fFinishTime > pStats->BestTimes[nBadTime].fFinishTime)
+    nBadTime = i;
       }
-	    
+      
       /* Should we replace it? */
       if(pStats->BestTimes[nBadTime].fFinishTime > fTime) {
-	/* Yup */
-	pStats->BestTimes[nBadTime].fFinishTime = fTime;
-	pStats->BestTimes[nBadTime].PlayerName = PlayerName;
-	pStats->BestTimes[nBadTime].Replay = Replay;
-	pStats->BestTimes[nBadTime].TimeStamp = TimeStamp;
+  /* Yup */
+  pStats->BestTimes[nBadTime].fFinishTime = fTime;
+  pStats->BestTimes[nBadTime].PlayerName = PlayerName;
+  pStats->BestTimes[nBadTime].Replay = Replay;
+  pStats->BestTimes[nBadTime].TimeStamp = TimeStamp;
       }
     }
   }
-	
+  
   /*===========================================================================
     Get global best time of level
     ===========================================================================*/
@@ -348,14 +348,14 @@ namespace vapp {
     PlayerTimeEntry *pBest = NULL;
     for(int i=0;i<m_Profiles.size();i++) {
       for(int j=0;j<m_Profiles[i]->LevelStats.size();j++) {
-	if(m_Profiles[i]->LevelStats[j]->LevelID == LevelID) {
-	  for(int k=0;k<m_Profiles[i]->LevelStats[j]->nNumBestTimes;k++) {
-	    if(pBest == NULL ||
-	       m_Profiles[i]->LevelStats[j]->BestTimes[k].fFinishTime < pBest->fFinishTime) {
-	      pBest = &m_Profiles[i]->LevelStats[j]->BestTimes[k];
-	    }
-	  }
-	}
+  if(m_Profiles[i]->LevelStats[j]->LevelID == LevelID) {
+    for(int k=0;k<m_Profiles[i]->LevelStats[j]->nNumBestTimes;k++) {
+      if(pBest == NULL ||
+         m_Profiles[i]->LevelStats[j]->BestTimes[k].fFinishTime < pBest->fFinishTime) {
+        pBest = &m_Profiles[i]->LevelStats[j]->BestTimes[k];
+      }
+    }
+  }
       }
     }
     
@@ -369,48 +369,48 @@ namespace vapp {
     /* Get best time of level */
     PlayerTimeEntry *pBest = NULL;
     PlayerProfile *pPlayer = getProfile(PlayerName);
-    if(pPlayer == NULL) return NULL;	  
+    if(pPlayer == NULL) return NULL;    
     for(int j=0;j<pPlayer->LevelStats.size();j++) {
       if(pPlayer->LevelStats[j]->LevelID == LevelID) {
-	for(int k=0;k<pPlayer->LevelStats[j]->nNumBestTimes;k++) {
-	  if(pBest == NULL ||
-	     pPlayer->LevelStats[j]->BestTimes[k].fFinishTime < pBest->fFinishTime) {
-	    pBest = &pPlayer->LevelStats[j]->BestTimes[k];
-	  }
-	}
+  for(int k=0;k<pPlayer->LevelStats[j]->nNumBestTimes;k++) {
+    if(pBest == NULL ||
+       pPlayer->LevelStats[j]->BestTimes[k].fFinishTime < pBest->fFinishTime) {
+      pBest = &pPlayer->LevelStats[j]->BestTimes[k];
+    }
+  }
       }
     }
     
     return pBest;
   }
-	
+  
   /*===========================================================================
     Create global top10 for level
     ===========================================================================*/
   std::vector<PlayerTimeEntry *> PlayerData::createLevelTop10(std::string LevelID) {
     std::vector<PlayerTimeEntry *> Top10;
-	  
+    
     for(int i=0;i<m_Profiles.size();i++) {
       for(int j=0;j<m_Profiles[i]->LevelStats.size();j++) {
-	if(m_Profiles[i]->LevelStats[j]->LevelID == LevelID) {
-	  for(int k=0;k<m_Profiles[i]->LevelStats[j]->nNumBestTimes;k++) {
-	    /* Merge this time into the top10 */
-	    bool bMerged = false;
-	    for(int z=0;z<Top10.size();z++) { 
-	      if(m_Profiles[i]->LevelStats[j]->BestTimes[k].fFinishTime < Top10[z]->fFinishTime) {
-		Top10.insert(Top10.begin() + z,&m_Profiles[i]->LevelStats[j]->BestTimes[k]);
-		bMerged = true;
-		break;
-	      }
-	    }
-            
-	    if(!bMerged && Top10.size() < 10) {
-	      Top10.push_back(&m_Profiles[i]->LevelStats[j]->BestTimes[k]);
-	    }
-	  }
-	}
+  if(m_Profiles[i]->LevelStats[j]->LevelID == LevelID) {
+    for(int k=0;k<m_Profiles[i]->LevelStats[j]->nNumBestTimes;k++) {
+      /* Merge this time into the top10 */
+      bool bMerged = false;
+      for(int z=0;z<Top10.size();z++) { 
+        if(m_Profiles[i]->LevelStats[j]->BestTimes[k].fFinishTime < Top10[z]->fFinishTime) {
+    Top10.insert(Top10.begin() + z,&m_Profiles[i]->LevelStats[j]->BestTimes[k]);
+    bMerged = true;
+    break;
+        }
       }
-    }	  
+            
+      if(!bMerged && Top10.size() < 10) {
+        Top10.push_back(&m_Profiles[i]->LevelStats[j]->BestTimes[k]);
+      }
+    }
+  }
+      }
+    }   
     
     return Top10;
   }
@@ -421,25 +421,25 @@ namespace vapp {
   std::vector<PlayerTimeEntry *> PlayerData::createPlayerOnlyLevelTop10(std::string PlayerName,std::string LevelID) {
     std::vector<PlayerTimeEntry *> Top10;
     PlayerProfile *pPlayer = getProfile(PlayerName);
-    if(pPlayer == NULL) return Top10;	  
-	  
+    if(pPlayer == NULL) return Top10;   
+    
     for(int j=0;j<pPlayer->LevelStats.size();j++) {
       if(pPlayer->LevelStats[j]->LevelID == LevelID) {
-	for(int k=0;k<pPlayer->LevelStats[j]->nNumBestTimes;k++) {
-	  /* Merge this time into the top10 */
-	  bool bMerged = false;
-	  for(int z=0;z<Top10.size();z++) { 
-	    if(pPlayer->LevelStats[j]->BestTimes[k].fFinishTime < Top10[z]->fFinishTime) {
-	      Top10.insert(Top10.begin() + z,&pPlayer->LevelStats[j]->BestTimes[k]);
-	      bMerged = true;
-	      break;
-	    }
-	  }
+  for(int k=0;k<pPlayer->LevelStats[j]->nNumBestTimes;k++) {
+    /* Merge this time into the top10 */
+    bool bMerged = false;
+    for(int z=0;z<Top10.size();z++) { 
+      if(pPlayer->LevelStats[j]->BestTimes[k].fFinishTime < Top10[z]->fFinishTime) {
+        Top10.insert(Top10.begin() + z,&pPlayer->LevelStats[j]->BestTimes[k]);
+        bMerged = true;
+        break;
+      }
+    }
           
-	  if(!bMerged && Top10.size() < 10) {
-	    Top10.push_back(&pPlayer->LevelStats[j]->BestTimes[k]);
-	  }
-	}
+    if(!bMerged && Top10.size() < 10) {
+      Top10.push_back(&pPlayer->LevelStats[j]->BestTimes[k]);
+    }
+  }
       }
     }
     
@@ -462,11 +462,11 @@ namespace vapp {
   void PlayerData::_FreePlayerData(void) {
     for(int i=0;i<m_Profiles.size();i++) {
       for(int j=0;j<m_Profiles[i]->LevelStats.size();j++)
-	delete m_Profiles[i]->LevelStats[j];
+  delete m_Profiles[i]->LevelStats[j];
       delete m_Profiles[i];
     }
-  }	    
-	
+  }     
+  
   /*===========================================================================
     Determine whether this level can be played by this player
     ===========================================================================*/
