@@ -32,7 +32,7 @@ namespace vapp {
   /*===========================================================================
   Rendering of the bike
   ===========================================================================*/
-  void GameRenderer::_RenderBike(BikeState *pBike, BikeParams *pBikeParms, BikerTheme *p_theme) {
+  void GameRenderer::_RenderBike(BikeState *pBike, BikeParameters *pBikeParms, BikerTheme *p_theme) {
     Sprite *pSprite;
     Texture *pTexture;
 
@@ -238,45 +238,13 @@ namespace vapp {
         p2 = pBike->LowerBodyP - Vector2f(-Sv.y,Sv.x)*0.24f - Sv*0.1f;
         p3 = pBike->ShoulderP - Vector2f(-Sv.y,Sv.x)*0.24f + Sv*0.46f;
 
-	pSprite = p_theme->getTorso();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);
-	  }
-	}        
-
-        /* Draw rider upper arm */
-        Sv = pBike->ShoulderP - pBike->ElbowP;
-        Sv.normalize();         
-        p0 = pBike->ShoulderP + Vector2f(-Sv.y,Sv.x)*0.12f;
-        p1 = pBike->ElbowP + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
-        p2 = pBike->ElbowP - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
-        p3 = pBike->ShoulderP - Vector2f(-Sv.y,Sv.x)*0.10f;
-
-	pSprite = p_theme->getUpperArm();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);
-	  }
-	}        
-
-        /* Draw rider lower arm */
-        Sv = pBike->ElbowP - pBike->HandP;
-        Sv.normalize();         
-        p0 = pBike->ElbowP + Vector2f(-Sv.y,Sv.x)*0.12f + Sv*0.09f;
-        p1 = pBike->HandP + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
-        p2 = pBike->HandP - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
-        p3 = pBike->ElbowP - Vector2f(-Sv.y,Sv.x)*0.10f + Sv*0.09f;
-        
-	pSprite = p_theme->getLowerArm();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p3,p2,p1,p0);
-	  }
-	}        
+	      pSprite = p_theme->getTorso();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);
+	        }
+	      }        
 
         /* Draw rider upper leg */
         Sv = pBike->LowerBodyP - pBike->KneeP;
@@ -286,13 +254,13 @@ namespace vapp {
         p2 = pBike->KneeP - Vector2f(-Sv.y,Sv.x)*0.15f + Sv*0.0f;
         p3 = pBike->LowerBodyP - Vector2f(-Sv.y,Sv.x)*0.1f + Sv*0.14f;
 
-	pSprite = p_theme->getUpperLeg();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);
-	  }
-	}        
+	      pSprite = p_theme->getUpperLeg();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);
+	        }
+	      }        
 
         /* Draw rider lower leg */
         Sv = pBike->KneeP - pBike->FootP;
@@ -302,13 +270,45 @@ namespace vapp {
         p2 = pBike->FootP - Vector2f(-Sv.y,Sv.x)*0.2f;
         p3 = pBike->KneeP - Vector2f(-Sv.y,Sv.x)*0.23f + Sv*0.1f;
 
-	pSprite = p_theme->getLowerLeg();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);        
-	  }
-	}
+	      pSprite = p_theme->getLowerLeg();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);        
+	        }
+	      }
+
+        /* Draw rider upper arm */
+        Sv = pBike->ShoulderP - pBike->ElbowP;
+        Sv.normalize();         
+        p0 = pBike->ShoulderP + Vector2f(-Sv.y,Sv.x)*0.12f;
+        p1 = pBike->ElbowP + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
+        p2 = pBike->ElbowP - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
+        p3 = pBike->ShoulderP - Vector2f(-Sv.y,Sv.x)*0.10f;
+
+	      pSprite = p_theme->getUpperArm();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p1,p2,p3,p0);
+	        }
+	      }        
+
+        /* Draw rider lower arm */
+        Sv = pBike->ElbowP - pBike->HandP;
+        Sv.normalize();         
+        p0 = pBike->ElbowP + Vector2f(-Sv.y,Sv.x)*0.12f + Sv*0.09f;
+        p1 = pBike->HandP + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
+        p2 = pBike->HandP - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
+        p3 = pBike->ElbowP - Vector2f(-Sv.y,Sv.x)*0.10f + Sv*0.09f;
+        
+	      pSprite = p_theme->getLowerArm();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p3,p2,p1,p0);
+	        }
+	      }        
       }
 
       if(m_bUglyMode || m_bTestThemeMode) {
@@ -335,45 +335,13 @@ namespace vapp {
         p2 = pBike->LowerBody2P - Vector2f(-Sv.y,Sv.x)*0.24f - Sv*0.1f;
         p3 = pBike->Shoulder2P - Vector2f(-Sv.y,Sv.x)*0.24f + Sv*0.46f;
 
-	pSprite = p_theme->getTorso();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
-	  }
-	}                
-
-        /* Draw rider upper arm */
-        Sv = pBike->Shoulder2P - pBike->Elbow2P;
-        Sv.normalize();         
-        p0 = pBike->Shoulder2P + Vector2f(-Sv.y,Sv.x)*0.12f;
-        p1 = pBike->Elbow2P + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
-        p2 = pBike->Elbow2P - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
-        p3 = pBike->Shoulder2P - Vector2f(-Sv.y,Sv.x)*0.10f;
-
-	pSprite = p_theme->getUpperArm();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
-	  }
-	}        
-
-        /* Draw rider lower arm */
-        Sv = pBike->Elbow2P - pBike->Hand2P;
-        Sv.normalize();         
-        p0 = pBike->Elbow2P + Vector2f(-Sv.y,Sv.x)*0.12f + Sv*0.09f;
-        p1 = pBike->Hand2P + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
-        p2 = pBike->Hand2P - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
-        p3 = pBike->Elbow2P - Vector2f(-Sv.y,Sv.x)*0.10f + Sv*0.09f;
-
-	pSprite = p_theme->getLowerArm();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);        
-	  }
-	}
+	      pSprite = p_theme->getTorso();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
+	        }
+	      }                
 
         /* Draw rider upper leg */
         Sv = pBike->LowerBody2P - pBike->Knee2P;
@@ -383,13 +351,13 @@ namespace vapp {
         p2 = pBike->Knee2P - Vector2f(-Sv.y,Sv.x)*0.15f + Sv*0.0f;
         p3 = pBike->LowerBody2P - Vector2f(-Sv.y,Sv.x)*0.1f + Sv*0.14f;
 
-	pSprite = p_theme->getUpperLeg();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p3,p2,p1,p0);        
-	  }
-	}
+	      pSprite = p_theme->getUpperLeg();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p3,p2,p1,p0);        
+	        }
+	      }
 
         /* Draw rider lower leg */
         Sv = pBike->Knee2P - pBike->Foot2P;
@@ -399,13 +367,45 @@ namespace vapp {
         p2 = pBike->Foot2P - Vector2f(-Sv.y,Sv.x)*0.2f;
         p3 = pBike->Knee2P - Vector2f(-Sv.y,Sv.x)*0.23f + Sv*0.1f;
 
-	pSprite = p_theme->getLowerLeg();
-	if(pSprite != NULL) {
-	  pTexture = pSprite->getTexture();
-	  if(pTexture != NULL) {
-	    _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
-	  }
-	}
+	      pSprite = p_theme->getLowerLeg();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
+	        }
+	      }
+
+        /* Draw rider upper arm */
+        Sv = pBike->Shoulder2P - pBike->Elbow2P;
+        Sv.normalize();         
+        p0 = pBike->Shoulder2P + Vector2f(-Sv.y,Sv.x)*0.12f;
+        p1 = pBike->Elbow2P + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
+        p2 = pBike->Elbow2P - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
+        p3 = pBike->Shoulder2P - Vector2f(-Sv.y,Sv.x)*0.10f;
+
+	      pSprite = p_theme->getUpperArm();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p2,p1,p0,p3);        
+	        }
+	      }        
+
+        /* Draw rider lower arm */
+        Sv = pBike->Elbow2P - pBike->Hand2P;
+        Sv.normalize();         
+        p0 = pBike->Elbow2P + Vector2f(-Sv.y,Sv.x)*0.12f + Sv*0.09f;
+        p1 = pBike->Hand2P + Vector2f(-Sv.y,Sv.x)*0.12f - Sv*0.05f;
+        p2 = pBike->Hand2P - Vector2f(-Sv.y,Sv.x)*0.10f - Sv*0.05f;
+        p3 = pBike->Elbow2P - Vector2f(-Sv.y,Sv.x)*0.10f + Sv*0.09f;
+
+	      pSprite = p_theme->getLowerArm();
+	      if(pSprite != NULL) {
+	        pTexture = pSprite->getTexture();
+	        if(pTexture != NULL) {
+	          _RenderAlphaBlendedSection(pTexture,p0,p1,p2,p3);        
+	        }
+	      }
       }
 
       if(m_bUglyMode || m_bTestThemeMode) {
@@ -425,15 +425,11 @@ namespace vapp {
     
     /* New wheel-spin particles? */
     if(getGameObject()->isWheelSpinning()) {
-      Particle *pPrevDebris = _GetNewestParticle(PT_DEBRIS);
-      
-      /* Limit particles to one every 0.01 seconds */
-      if(pPrevDebris==NULL || getGameObject()->getTime() - pPrevDebris->fSpawnTime > 0.01f) {      
-        if(randomNum(0,1) < 0.8f) {
-          Particle *pNewParticle = spawnParticle(PT_DEBRIS,getGameObject()->getWheelSpinPoint(),
-                                                getGameObject()->getWheelSpinDir(),4);
-          pNewParticle->bFront = false;                                              
-        }                                             
+      if(randomNum(0,1) < 0.7f) {
+	      ParticlesSource *v_debris;
+	      v_debris = (ParticlesSource*) &(getGameObject()->getLevelSrc()->getEntityById("BikeDebris"));
+	      v_debris->setDynamicPosition(getGameObject()->getWheelSpinPoint());	
+	      v_debris->addParticle(getGameObject()->getWheelSpinDir(), m_pMotoGame->getTime() + 3.0);
       }
     }
   }
