@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
 #include "Theme.h"
-#include "VExcept.h"
+#include "helpers/VExcept.h"
 #include "VXml.h"
 #include "VApp.h"
 #include "BuiltInFont.h"
@@ -67,7 +67,7 @@ void Theme::initDefaultFont() {
     
     /* Load it */
     m_pDefaultFontTexture = m_texMan.createTexture("default-font",(unsigned char *)pImgData,
-						   256,256,true);
+               256,256,true);
       
     delete [] pImgData;
 }
@@ -83,33 +83,33 @@ Theme::Theme() {
   m_pDefaultFontTexture = NULL;
 
   m_player = new BikerTheme(this,
-			    THEME_PLAYER_BODY,
-			    THEME_PLAYER_FRONT,
-			    THEME_PLAYER_REAR,
-			    THEME_PLAYER_WHEEL,
-			    THEME_PLAYER_LOWERARM,
-			    THEME_PLAYER_LOWERLEG,
-			    THEME_PLAYER_TORSO,
-			    THEME_PLAYER_UPPERARM,
-			    THEME_PLAYER_UPPERLEG,
-			    THEME_PLAYER_UGLYRIDERCOLOR,
-			    THEME_PLAYER_UGLYWHEELCOLOR
-			    );
+          THEME_PLAYER_BODY,
+          THEME_PLAYER_FRONT,
+          THEME_PLAYER_REAR,
+          THEME_PLAYER_WHEEL,
+          THEME_PLAYER_LOWERARM,
+          THEME_PLAYER_LOWERLEG,
+          THEME_PLAYER_TORSO,
+          THEME_PLAYER_UPPERARM,
+          THEME_PLAYER_UPPERLEG,
+          THEME_PLAYER_UGLYRIDERCOLOR,
+          THEME_PLAYER_UGLYWHEELCOLOR
+          );
 
 #if defined(ALLOW_GHOST)
   m_ghost = new BikerTheme(this,
-			   THEME_GHOST_BODY,
-			   THEME_GHOST_FRONT,
-			   THEME_GHOST_REAR,
-			   THEME_GHOST_WHEEL,
-			   THEME_GHOST_LOWERARM,
-			   THEME_GHOST_LOWERLEG,
-			   THEME_GHOST_TORSO,
-			   THEME_GHOST_UPPERARM,
-			   THEME_GHOST_UPPERLEG,
-			   THEME_GHOST_UGLYRIDERCOLOR,
-			   THEME_GHOST_UGLYWHEELCOLOR
-			   );
+         THEME_GHOST_BODY,
+         THEME_GHOST_FRONT,
+         THEME_GHOST_REAR,
+         THEME_GHOST_WHEEL,
+         THEME_GHOST_LOWERARM,
+         THEME_GHOST_LOWERLEG,
+         THEME_GHOST_TORSO,
+         THEME_GHOST_UPPERARM,
+         THEME_GHOST_UPPERLEG,
+         THEME_GHOST_UGLYRIDERCOLOR,
+         THEME_GHOST_UGLYWHEELCOLOR
+         );
 #endif
 }
 
@@ -123,6 +123,10 @@ Theme::~Theme() {
   m_texMan.unloadTextures();
 }
  
+std::string Theme::Name() const {
+  return m_name;
+}
+
 vapp::Texture* Theme::loadTexture(std::string p_fileName, bool bSmall, bool bClamp, vapp::FilterMode eFilterMode) {
   return m_texMan.loadTexture(p_fileName.c_str(), bSmall, bClamp, eFilterMode);
 }
@@ -132,6 +136,10 @@ std::vector<std::string>* Theme::getRequiredFiles() {
 }
 
 void Theme::load(std::string p_themeFile) {
+  vapp::Log(std::string("Loading theme from file " + p_themeFile).c_str());
+
+  cleanSprites(); /* removing existing sprites */
+
   vapp::XMLDocument v_ThemeXml;
   TiXmlDocument *v_ThemeXmlData;
   TiXmlElement *v_ThemeXmlDataElement;
@@ -144,7 +152,7 @@ void Theme::load(std::string p_themeFile) {
     v_ThemeXmlData = v_ThemeXml.getLowLevelAccess();
     
     if(v_ThemeXmlData == NULL) {
-      throw vapp::Exception("unable to analyze xml theme file");
+      throw Exception("unable to analyze xml theme file");
     }
     
     /* read the theme name */
@@ -155,14 +163,14 @@ void Theme::load(std::string p_themeFile) {
     }
     
     if(m_name == "") {
-      throw vapp::Exception("unnamed theme");
+      throw Exception("unnamed theme");
     }
     
     /* get sprites */
     loadSpritesFromXML(v_ThemeXmlDataElement);
 
-  } catch(vapp::Exception &e) {
-    throw vapp::Exception("unable to analyze xml theme file");
+  } catch(Exception &e) {
+    throw Exception("unable to analyze xml theme file");
   }
 }
 
@@ -215,7 +223,7 @@ Sprite* Theme::getSprite(enum SpriteType pSpriteType, std::string pName) {
   for(unsigned int i=0; i<m_sprites.size(); i++) {
     if(m_sprites[i]->getType() == pSpriteType) {
       if(m_sprites[i]->getName() == pName) {
-	return m_sprites[i];
+  return m_sprites[i];
       }
     }
   }
@@ -365,12 +373,12 @@ void Theme::newDecorationSpriteFromXML(TiXmlElement *pVarElem) {
   if(pc != NULL) v_blendmode = pc;
 
   m_sprites.push_back(new DecorationSprite(this, v_name, v_fileName,
-					   atof(v_width.c_str()),
-					   atof(v_height.c_str()),
-					   atof(v_centerX.c_str()),
-					   atof(v_centerY.c_str()),
-					   strToBlendMode(v_blendmode)
-					   ));
+             atof(v_width.c_str()),
+             atof(v_height.c_str()),
+             atof(v_centerX.c_str()),
+             atof(v_centerY.c_str()),
+             strToBlendMode(v_blendmode)
+             ));
   m_requiredFiles.push_back(THEME_DECORATION_SPRITE_FILE_DIR + std::string("/") + v_fileName);
 }
 
@@ -415,8 +423,8 @@ void Theme::newEdgeEffectSpriteFromXML(TiXmlElement *pVarElem) {
   v_depth = pc;
 
   m_sprites.push_back(new EdgeEffectSprite(this, v_name, v_fileName,
-					   atof(v_scale.c_str()),
-					   atof(v_depth.c_str())));
+             atof(v_scale.c_str()),
+             atof(v_depth.c_str())));
   m_requiredFiles.push_back(THEME_EDGEEFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName);
 }
 
@@ -512,11 +520,11 @@ vapp::Texture* Sprite::getTexture(bool bSmall, bool bClamp, vapp::FilterMode eFi
   v_currentTexture = getCurrentTexture();
   if(v_currentTexture == NULL) {
     v_currentTexture = m_associated_theme->loadTexture(getCurrentTextureFileName(),
-						       bSmall,
-						       bClamp,
-						       eFilterMode);
+                   bSmall,
+                   bClamp,
+                   eFilterMode);
     if(v_currentTexture == NULL) { 
-      throw vapp::Exception("Unable to load texture '" + getCurrentTextureFileName() + "'");
+      throw Exception("Unable to load texture '" + getCurrentTextureFileName() + "'");
     }
     setCurrentTexture(v_currentTexture);
   }
@@ -616,11 +624,11 @@ void AnimationSprite::cleanFrames() {
 }
 
 AnimationSpriteFrame::AnimationSpriteFrame(AnimationSprite *p_associatedAnimationSprite,
-					   float p_centerX,
-					   float p_centerY,
-					   float p_width,
-					   float p_height,
-					   float p_delay
+             float p_centerX,
+             float p_centerY,
+             float p_width,
+             float p_height,
+             float p_delay
     ) {
   m_associatedAnimationSprite = p_associatedAnimationSprite;
   m_texture = NULL;
@@ -827,28 +835,28 @@ void SimpleFrameSprite::setCurrentTexture(vapp::Texture *p_texture) {
 }
 
 BikerTheme::BikerTheme(Theme* p_associated_theme,
-		       std::string p_Body,
-		       std::string p_Front,
-		       std::string p_Rear,
-		       std::string p_Wheel,
-		       std::string p_LowerArm,
-		       std::string p_LowerLeg,
-		       std::string p_Torso,
-		       std::string p_UpperArm,
-		       std::string p_UpperLeg,
-		       vapp::Color p_UglyRiderColor,
-		       vapp::Color p_UglyWheelColor
-		       ) {
+           std::string p_Body,
+           std::string p_Front,
+           std::string p_Rear,
+           std::string p_Wheel,
+           std::string p_LowerArm,
+           std::string p_LowerLeg,
+           std::string p_Torso,
+           std::string p_UpperArm,
+           std::string p_UpperLeg,
+           vapp::Color p_UglyRiderColor,
+           vapp::Color p_UglyWheelColor
+           ) {
   m_associated_theme = p_associated_theme;
-  m_Body     	     = p_Body;
-  m_Front    	     = p_Front;
-  m_Rear     	     = p_Rear;
-  m_Wheel    	     = p_Wheel; 
-  m_LowerArm 	     = p_LowerArm;
-  m_LowerLeg 	     = p_LowerLeg;
-  m_Torso    	     = p_Torso;
-  m_UpperArm 	     = p_UpperArm;
-  m_UpperLeg 	     = p_UpperLeg;
+  m_Body           = p_Body;
+  m_Front          = p_Front;
+  m_Rear           = p_Rear;
+  m_Wheel          = p_Wheel; 
+  m_LowerArm       = p_LowerArm;
+  m_LowerLeg       = p_LowerLeg;
+  m_Torso          = p_Torso;
+  m_UpperArm       = p_UpperArm;
+  m_UpperLeg       = p_UpperLeg;
 
   m_UglyRiderColor = p_UglyRiderColor;
   m_UglyWheelColor = p_UglyWheelColor;
@@ -912,7 +920,7 @@ bool ThemeChoicer::ExistThemeName(std::string p_themeName) {
 
 #if defined(SUPPORT_WEBACCESS)
   ThemeChoicer::ThemeChoicer(vapp::WWWAppInterface *p_WebApp,
-			     const ProxySettings *p_proxy_settings) {			     			     
+           const ProxySettings *p_proxy_settings) {                    
 #else
   ThemeChoicer::ThemeChoicer(void) {  
 #endif
@@ -979,14 +987,14 @@ void ThemeChoicer::initList() {
   for(unsigned int i=0; i<v_themesFiles.size(); i++) {
     try {
       if(vapp::FS::isInUserDir(v_themesFiles[i])) {
-	v_name = getThemeNameFromFile(v_themesFiles[i]);
-	if(ExistThemeName(v_name) == false) {
-	  m_choices.push_back(new ThemeChoice(v_name, v_themesFiles[i], true));
-	} else {
-	  vapp::Log(std::string("Theme " + v_name + " is present several times").c_str());
-	}
+  v_name = getThemeNameFromFile(v_themesFiles[i]);
+  if(ExistThemeName(v_name) == false) {
+    m_choices.push_back(new ThemeChoice(v_name, v_themesFiles[i], true));
+  } else {
+    vapp::Log(std::string("Theme " + v_name + " is present several times").c_str());
+  }
       }
-    } catch(vapp::Exception &e) {
+    } catch(Exception &e) {
       /* anyway, give up this theme */
     }
   }
@@ -995,15 +1003,15 @@ void ThemeChoicer::initList() {
   for(unsigned int i=0; i<v_themesFiles.size(); i++) {
     try {
       if(vapp::FS::isInUserDir(v_themesFiles[i]) == false) {
-	v_name = getThemeNameFromFile(v_themesFiles[i]);
-	if(ExistThemeName(v_name) == false) {
-	  m_choices.push_back(new ThemeChoice(v_name, v_themesFiles[i], true));
-	} else {
-	  // no warning for non user dir
-	  // vapp::Log(std::string("Theme " + v_name + " is present several times").c_str());
-	}
+  v_name = getThemeNameFromFile(v_themesFiles[i]);
+  if(ExistThemeName(v_name) == false) {
+    m_choices.push_back(new ThemeChoice(v_name, v_themesFiles[i], true));
+  } else {
+    // no warning for non user dir
+    // vapp::Log(std::string("Theme " + v_name + " is present several times").c_str());
+  }
       }
-    } catch(vapp::Exception &e) {
+    } catch(Exception &e) {
       /* anyway, give up this theme */
     }
   }
@@ -1016,29 +1024,29 @@ void ThemeChoicer::initList() {
         
     for(unsigned int i=0; i<v_availableThemes.size(); i++) {
       if(ExistThemeName(v_availableThemes[i]->getName()) == false) {
-	/* this theme is avaible */
-	m_choices.push_back(new ThemeChoice(v_availableThemes[i]->getName(), "", false));
+  /* this theme is avaible */
+  m_choices.push_back(new ThemeChoice(v_availableThemes[i]->getName(), "", false));
       } else {
-	/* the theme already exists ; check sum */
-	for(unsigned int j=0; j<m_choices.size(); j++) {
+  /* the theme already exists ; check sum */
+  for(unsigned int j=0; j<m_choices.size(); j++) {
 
-	  if(m_choices[j]->ThemeName() == v_availableThemes[i]->getName()) {
-	    std::string v_localMd5;
-	    try {
-	      v_localMd5 = md5file(m_choices[j]->ThemeFile());
-	    } catch(vapp::Exception &e) {
-	      v_localMd5 = "";
-	    }
-	    
-	    if(v_localMd5 != v_availableThemes[i]->getSum()) {
-	      /* this theme can be updated */
-	      m_choices[j]->setRequireUpdate(true);
-	    }
-	  }
-	}
+    if(m_choices[j]->ThemeName() == v_availableThemes[i]->getName()) {
+      std::string v_localMd5;
+      try {
+        v_localMd5 = md5file(m_choices[j]->ThemeFile());
+      } catch(Exception &e) {
+        v_localMd5 = "";
+      }
+      
+      if(v_localMd5 != v_availableThemes[i]->getSum()) {
+        /* this theme can be updated */
+        m_choices[j]->setRequireUpdate(true);
       }
     }
-  } catch(vapp::Exception &e) {
+  }
+      }
+    }
+  } catch(Exception &e) {
     /* hum, sorry, you will not see avaible theme to download */
   }
 #endif
@@ -1056,7 +1064,7 @@ std::string ThemeChoicer::getThemeNameFromFile(std::string p_themeFile) {
   v_ThemeXmlData = v_ThemeXml.getLowLevelAccess();
   
   if(v_ThemeXmlData == NULL) {
-    throw vapp::Exception("error : unable analyse xml theme file");
+    throw Exception("error : unable analyse xml theme file");
   }
   
   /* read the theme name */
@@ -1067,7 +1075,7 @@ std::string ThemeChoicer::getThemeNameFromFile(std::string p_themeFile) {
   }
   
   if(m_name == "") {
-    throw vapp::Exception("error : the theme has no name !");
+    throw Exception("error : the theme has no name !");
   }
   
   return m_name;
@@ -1093,9 +1101,9 @@ void ThemeChoicer::updateThemeFromWWW(ThemeChoice* pThemeChoice) {
 #endif
 
 ThemeChoice::ThemeChoice(std::string p_themeName, std::string p_themeFile, bool p_hosted) {
-  m_themeName 	  = p_themeName;
-  m_themeFile 	  = p_themeFile;
-  m_hosted    	  = p_hosted;
+  m_themeName     = p_themeName;
+  m_themeFile     = p_themeFile;
+  m_hosted        = p_hosted;
   m_requireUpdate = false;
 }
 
