@@ -23,12 +23,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __VBEZIER_H__
 
 #include "VCommon.h"
-#include "VMath.h"
+#include "helpers/VMath.h"
 
 namespace vapp {
 
-	/*===========================================================================
-	Cubic bezier curve
+  /*===========================================================================
+  Cubic bezier curve
   ===========================================================================*/
   class BezierCurve {
     public:
@@ -56,16 +56,16 @@ namespace vapp {
       Vector3f m_P[4];        /* Coefficients */
   };
 
-	/*===========================================================================
-	Bezier shape point
+  /*===========================================================================
+  Bezier shape point
   ===========================================================================*/
   struct BezierShapePoint {
     Vector3f Pos;             /* Position of point */
     Vector3f c1,c2;           /* Control points */
   };
 
-	/*===========================================================================
-	Bezier shape
+  /*===========================================================================
+  Bezier shape
   ===========================================================================*/
   class BezierShape {
     public:
@@ -106,6 +106,6 @@ namespace vapp {
       float m_fLength;
   };  
   
-};
+}
 
 #endif
