@@ -70,8 +70,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <string>
 #include <vector>
 #include <queue>
-#include <ostream>
-#include <istream>
+#include <iostream>
 #include <sstream>
 
 #include <stdio.h>
