@@ -25,6 +25,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VCommon.h"
 #include "tinyxml/tinyxml.h"
 
+#ifdef WIN32
+  #include <io.h>
+#else
+  #include <unistd.h>
+  #include <sys/types.h>
+  #include <dirent.h>
+#endif
+
 namespace vapp {
 
 	/*===========================================================================
@@ -86,8 +94,8 @@ namespace vapp {
       
       static std::vector<std::string> findPhysFiles(std::string Files,bool bRecurse = false);
       
-      static bool copyFile(const std::string &From,const std::string &To);
-      static void deleteFile(const std::string &File);
+      static bool copyFile(const std::string &From,const std::string &To, std::string &To_really_done); /* To_really_done is out : it is the name of the file really written */
+      static bool deleteFile(const std::string &File);
       
       static void writeLog(const std::string &s);
       static FileHandle *openOFile(std::string Path);
@@ -133,6 +141,11 @@ namespace vapp {
       static int readInt_LE(FileHandle *pfh);
       static float readFloat_LE(FileHandle *pfh);      
       
+      /* Allow caller to specify that the order is wrong. */
+      static int readShort_MaybeLE(FileHandle *pfh, bool big); 
+      static int readInt_MaybeLE(FileHandle *pfh, bool big); 
+      static float readFloat_MaybeLE(FileHandle *pfh, bool big); 
+      
       /* For buffered reading: */
       static int readBufferedChar(FileHandle *pfh);
       static int peekNextBufferedChar(FileHandle *pfh); 
@@ -179,7 +192,7 @@ namespace vapp {
       static PackFile m_PackFiles[MAX_PACK_FILES];
   };
 
-};
+}
 
 #endif
 
